package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.30.1 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.30.1) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@("`0`````````````#`!8````!````````(D@`````````0```````
M`*%0``````!``#@`"`!``!8`%0````8````$`````````$``````````0```
M``````!``````````<`````````!P``````````(`````P````0````````"
M``````````(``````````@``````````&``````````8``````````$````!
M````!0```````````````````````````````````````)E@````````F6``
M```````0``````$````&````````F]@```````"KV````````*O8````````
M!*`````````5`````````!```````@````8```````";^````````*OX````
M````J_@````````!H`````````&@``````````AD=.50````!````````).<
M````````DYP```````"3G`````````#4`````````-0`````````!&1TY5$`
M```&````````````````````````````````````````````````````````
M```````09'3E4@````0```````";V````````*O8````````J]@````````$
M*`````````0H``````````$O;&EB+VQD+6UU<VPM<S,Y,'@N<V\N,0`````1
M````20````0````(@`1`!0`0$""$`(:`!!``*`D$``D``"&""`($ND$8@(@`
M````````20```$T```!1````4@```%@```!9````6@````````!<````70``
M``````!>````7P```&$``````````'R:?VH.[]/J+4?>SA_?Q6^VF\4N#O&-
MN'S49-0.Y/\A'%AQV6!LH?HL/^7";XL!LH?7^D(!QD?B?)+CN](\PU5FS*]G
MTW`'B.S514/MVV(SS"6,%9N<J7\*`J?@4)X::TG[X*,`````````````````
M`````````````````````P``!P```````!AP```````````````,$@``````
M``````````````````````&S$@`````````````````````````````4$0``
M``````````````````````````'9$0````````````````````````````%5
M$@`````````````````````````````;$@``````````````````````````
M``&2$@`````````````````````````````C$@``````````````````````
M```````J$@````````````````````````````'F$@``````````````````
M``````````&>$@`````````````````````````````S(```````````````
M``````````````,8(0````````````````````````````!+$@``````````
M``````````````````!1$@````````````````````````````+E$@``````
M``````````````````````+6$@````````````````````````````)K$@``
M``````````````````````````(,$@````````````````````````````!8
M$@````````````````````````````*@$@``````````````````````````
M``!?$@````````````````````````````!G$@``````````````````````
M``````*)$@````````````````````````````!O$@``````````````````
M``````````!U$@````````````````````````````!^(```````````````
M``````````````+/$@````````````````````````````":$@``````````
M``````````````````"?$@````````````````````````````'W$0``````
M``````````````````````*G$@````````````````````````````(Y$@``
M``````````````````````````"F$@````````````````````````````(K
M$@````````````````````````````,\$@``````````````````````````
M``,7$0````````````````````````````)=$@``````````````````````
M``````,$$@````````````````````````````,9$0``````````````````
M``````````"M$@````````````````````````````+\$@``````````````
M``````````````%C$@````````````````````````````"V(@``````````
M``````````````````#%(`````````````````````````````#;$@``````
M``````````````````````+'$@````````````````````````````))$@``
M``````````````````````````#@$@````````````````````````````#F
M(`````````````````````````````*4$@``````````````````````````
M``$`$@````````````````````````````&#$@``````````````````````
M``````$%$@````````````````````````````)Y$@``````````````````
M``````````%R$@````````````````````````````$+$@``````````````
M``````````````$<$@````````````````````````````('$@``````````
M``````````````````!P$@````````````````````````````(8$@``````
M``````````````````````)2$@````````````````````````````+U$@``
M``````````````````````````$B$@````````````````````````````+M
M$@````````````````````````````$V$@``````````````````````````
M``("$@````````````````````````````'!$@``````````````````````
M``````$]$@````````````````````````````,6(0``````````````````
M``````````%.$@````````````````````````````,1$@``"0```````"`8
M`````````BH```'3$@``"@```````%8(``````````(```-^$@``"0``````
M`#((````````!DH```0J$@``"0```````#P8`````````&P```-;$@``"0``
M`````"O@``````````8```/H$@``!P```````!AP``````````(```.A$@``
M"0```````#A8`````````\````0.$@``"0```````"OH`````````>X```/9
M$```$P```````+!X``````````````-L$@``"0```````#%8`````````*P`
M``.+$@``"0```````"HH`````````#P```.3$@``"0```````#"X````````
M`'````.W$@``"0```````%-``````````6````/,$@``"0```````"W8````
M`````!X```0E$```$P```````,#8``````````````,A$@``"0```````")X
M`````````#P```/N$@``"0```````"WX`````````38```/"$0``$@``````
M`+!P``````````@```0'$```$@```````+!X``````````````/>$@``"0``
M`````")(``````````````/E$@``"0```````%+0`````````&P```,J$@``
M"0```````#$H`````````"X```-%$@``"0```````"K(`````````18```0;
M$@``"0```````%2@`````````1@```/Z$@``"0```````"\P`````````8@`
M;&EB<&5R;"YS;P!O<&5N9&ER`'-T9&5R<@!R96%L;&]C`&%C8V5S<P!S;G!R
M:6YT9@!?7V1E<F5G:7-T97)?9G)A;65?:6YF;P!L<V5E:P!G971P:60`=6YL
M:6YK`&UE;6UO=F4`<W1R;F-M<`!L<W1A=`!C;&]S961I<@!?251-7V1E<F5G
M:7-T97)434-L;VYE5&%B;&4`;W!E;@!S=')S='(`<W1R8VAR`')E861L:6YK
M`%]?8WAA7V9I;F%L:7IE`%]?<F5G:7-T97)?9G)A;65?:6YF;P!E>&ET`&-L
M;W-E`%])5$U?<F5G:7-T97)434-L;VYE5&%B;&4`<F5A9`!R;61I<@!?7V5R
M<FYO7VQO8V%T:6]N`&UK9&ER`'!T:')E861?9V5T<W!E8VEF:6,`;65M8W!Y
M`%]?<W1A8VM?8VAK7V9A:6P`9V5T=6ED`%!E<FQ?<WES7W1E<FT`4&5R;%]S
M>7-?:6YI=#,`4&5R;%]A=&9O<FM?;&]C:P!P97)L7V-O;G-T<G5C=`!097)L
M7V=E=%]S=@!097)L7V-R;V%K7VYO8V]N=&5X=`!097)L7V%V7W-H:69T`%!E
M<FQ?<W9?,G!V7V9L86=S`%]F:6YI`%!,7V1O7W5N9'5M<`!097)L7VYE=UA3
M7V9L86=S`%!,7W1H<E]K97D`<&5R;%]F<F5E`%!E<FQ?;6=?<V5T`%!E<FQ?
M871F;W)K7W5N;&]C:P!097)L7W-V7W-E='!V`%!E<FQ?9W9?9F5T8VAP=@!P
M97)L7W)U;@!097)L7VYE=UA3`'!E<FQ?9&5S=')U8W0`4&5R;%]A=E]F971C
M:`!B;V]T7T1Y;F%,;V%D97(`<&5R;%]P87)S90!097)L7W-A9F5S>7-M86QL
M;V,`<&5R;%]A;&QO8P!L:6)C+FUU<VPM<S,Y,'@N<V\N,0!F<')I;G1F`'-T
M<F1U<`!P=&AR96%D7V%T9F]R:P!R96%D9&ER`'-P<FEN=&8`<W1R=&]K`'-T
M<FYC<'D`7U]L:6)C7W-T87)T7VUA:6X`7U]?96YV:7)O;@!?<W1A<G1?8P!G
M971?=7-E<FYA;65?9G)O;5]G971P=W5I9`!P87)?8W5R<F5N=%]E>&5C7W!R
M;V,`<&%R7V-U<G)E;G1?97AE8P!P87)?<V5T=7!?;&EB<&%T:`!P87)?;6MT
M;7!D:7(`>'-?:6YI=`!P87)?96YV7V-L96%N`%A37TEN=&5R;F%L<U]005)?
M0D]/5`!S:&%?=7!D871E`&UY7W!A<E]P;`!P87)?8F%S96YA;64`7U]B<W-?
M<W1A<G0`<VAA7VEN:70`<&%R7V1I<FYA;64`<&%R7VEN:71?96YV`%]E9&%T
M80!P87)?9FEN9'!R;V<`<VAA7V9I;F%L`%]E;F0`<&%R7V-L96%N=7``+W5S
M<B]L:6(O<&5R;#4O8V]R95]P97)L+T-/4D4``````````````*^(````````
M``P````````@&````````*^@``````````P```````!6"````````*^X````
M``````P````````8<````````+````````````P```````"P`````````+`0
M``````````P```````!6*@```````+`8``````````P```````!6,```````
M`+`H``````````P```````!6,@```````+`P``````````P```````!6-@``
M`````+`X``````````P```````!6/@```````+!```````````P```````!6
MJ@```````+!(``````````P```````!61@```````+!8``````````P`````
M``!62@```````+!@``````````P```````!64````````+!P``````````P`
M``````!9#````````*^0````!`````H``````````````````*^8````!0``
M``H``````````````````*^H````#0````H``````````````````*^P````
M'`````H``````````````````*_`````(`````H``````````````````*_(
M````*0````H``````````````````*_0````+0````H`````````````````
M`*_8````+@````H``````````````````*_@````,P````H`````````````
M`````*_H````.`````H``````````````````*_P````.0````H`````````
M`````````*_X````/@````H``````````````````*VP`````@````L`````
M`````````````*VX`````P````L``````````````````*W`````!@````L`
M`````````````````*W(````!P````L``````````````````*W0````"```
M``L``````````````````*W8````"0````L``````````````````*W@````
M"@````L``````````````````*WH````"P````L``````````````````*WP
M````#`````L``````````````````*WX````#0````L`````````````````
M`*X`````#P````L``````````````````*X(````$`````L`````````````
M`````*X0````$0````L``````````````````*X8````$@````L`````````
M`````````*X@````$P````L``````````````````*XH````%`````L`````
M`````````````*XP````%0````L``````````````````*XX````%@````L`
M`````````````````*Y`````%P````L``````````````````*Y(````&```
M``L``````````````````*Y0````&0````L``````````````````*Y8````
M&@````L``````````````````*Y@````&P````L``````````````````*YH
M````'0````L``````````````````*YP````'@````L`````````````````
M`*YX````'P````L``````````````````*Z`````(0````L`````````````
M`````*Z(````(@````L``````````````````*Z0````(P````L`````````
M`````````*Z8````)`````L``````````````````*Z@````)0````L`````
M`````````````*ZH````)P````L``````````````````*ZP````*`````L`
M`````````````````*ZX````*@````L``````````````````*[`````*P``
M``L``````````````````*[(````+`````L``````````````````*[0````
M+0````L``````````````````*[8````+@````L``````````````````*[@
M````+P````L``````````````````*[H````,`````L`````````````````
M`*[P````,0````L``````````````````*[X````,@````L`````````````
M`````*\`````-`````L``````````````````*\(````-0````L`````````
M`````````*\0````-@````L``````````````````*\8````-P````L`````
M`````````````*\@````.@````L``````````````````*\H````.P````L`
M`````````````````*\P````/`````L``````````````````*\X````/0``
M``L``````````````````*]`````/P````L``````````````````*](````
M0`````L``````````````````*]0````00````L``````````````````*]8
M````0@````L``````````````````*]@````0P````L`````````````````
M`*]H````1`````L``````````````````*]P````10````L`````````````
M`````*]X````1@````L``````````````````*^`````2`````L`````````
M`.OO\'``)+D$``^G^_]@XP#P```DP.4```6NP.4``!Z7Z^_Q$``$!_[C$/`X
M`"3`$```2GW2!_`P$`CC$!`0``0'\0<`!P`'`,`0``!*?.,0$```!`?Q#1#C
M$!`,`!3`]/___^4`````P!```$IPXQ`0```$!_$-$.,0$`P`%,#T____U0``
M`!C`$```2F3C$!````0'\0T0XQ`0#``4P/3____%````,,`0``!*6.,0$```
M!`?Q#1#C$!`,`!3`]/___[4```!(P!```$I,XQ`0```$!_$-$.,0$`P`%,#T
M____I0```&#`$```2D#C$!````0'\0T0XQ`0#``4P/3___^5````>,`0``!*
M-.,0$```!`?Q#1#C$!`,`!3`]/___X4```"0P!```$HHXQ`0```$!_$-$.,0
M$`P`%,#T____=0```*C`$```2ASC$!````0'\0T0XQ`0#``4P/3___]E````
MP,`0``!*$.,0$```!`?Q#1#C$!`,`!3`]/___U4```#8P!```$H$XQ`0```$
M!_$-$.,0$`P`%,#T____10```/#`$```2?CC$!````0'\0T0XQ`0#``4P/3_
M__\U```!",`0``!)[.,0$```!`?Q#1#C$!`,`!3`]/___R4```$@P!```$G@
MXQ`0```$!_$-$.,0$`P`%,#T____%0```3C`$```2=3C$!````0'\0T0XQ`0
M#``4P/3___\%```!4,`0``!)R.,0$```!`?Q#1#C$!`,`!3`]/___O4```%H
MP!```$F\XQ`0```$!_$-$.,0$`P`%,#T___^Y0```8#`$```2;#C$!````0'
M\0T0XQ`0#``4P/3___[5```!F,`0``!)I.,0$```!`?Q#1#C$!`,`!3`]/__
M_L4```&PP!```$F8XQ`0```$!_$-$.,0$`P`%,#T___^M0```<C`$```28SC
M$!````0'\0T0XQ`0#``4P/3___ZE```!X,`0``!)@.,0$```!`?Q#1#C$!`,
M`!3`]/___I4```'XP!```$ETXQ`0```$!_$-$.,0$`P`%,#T___^A0```A#`
M$```26CC$!````0'\0T0XQ`0#``4P/3___YU```"*,`0``!)7.,0$```!`?Q
M#1#C$!`,`!3`]/___F4```)`P!```$E0XQ`0```$!_$-$.,0$`P`%,#T___^
M50```EC`$```243C$!````0'\0T0XQ`0#``4P/3___Y%```"<,`0``!)..,0
M$```!`?Q#1#C$!`,`!3`]/___C4```*(P!```$DLXQ`0```$!_$-$.,0$`P`
M%,#T___^)0```J#`$```22#C$!````0'\0T0XQ`0#``4P/3___X5```"N,`0
M``!)%.,0$```!`?Q#1#C$!`,`!3`]/___@4```+0P!```$D(XQ`0```$!_$-
M$.,0$`P`%,#T___]]0```NC`$```2/SC$!````0'\0T0XQ`0#``4P/3___WE
M```#`,`0``!(\.,0$```!`?Q#1#C$!`,`!3`]/___=4```,8P!```$CDXQ`0
M```$!_$-$.,0$`P`%,#T___]Q0```S#`$```2-CC$!````0'\0T0XQ`0#``4
MP/3___VU```#2,`0``!(S.,0$```!`?Q#1#C$!`,`!3`]/___:4```-@P!``
M`$C`XQ`0```$!_$-$.,0$`P`%,#T___]E0```WC`$```2+3C$!````0'\0T0
MXQ`0#``4P/3___V%```#D,`0``!(J.,0$```!`?Q#1#C$!`,`!3`]/___74`
M``.HP!```$B<XQ`0```$!_$-$.,0$`P`%,#T___]90```\#`$```2)#C$!``
M``0'\0T0XQ`0#``4P/3___U5```#V,`0``!(A.,0$```!`?Q#1#C$!`,`!3`
M]/___44```/PP!```$AXXQ`0```$!_$-$.,0$`P`%,#T___]-0``!`C`$```
M2&SC$!````0'\0T0XQ`0#``4P/3___TE```$(,`0``!(8.,0$```!`?Q#1#C
M$!`,`!3`]/___14```0XP!```$A4XQ`0```$!_$-$.,0$`P`%,#T___]!0``
M!%#`$```2$CC$!````0'\0T0XQ`0#``4P/3___SU```$:,`0``!(/.,0$```
M!`?Q#1#C$!`,`!3`]/___.4```2`P!```$@PXQ`0```$!_$-$.,0$`P`%,#T
M___\U0``!)C`$```2"3C$!````0'\0T0XQ`0#``4P/3___S%```$L,`0``!(
M&.,0$```!`?Q#1#C$!`,`!3`]/___+4```3(P!```$@,XQ`0```$!_$-$.,0
M$`P`%,#T___\I0``!.#`$```2`#C$!````0'\0T0XQ`0#``4P/3___R5```$
M^,`0``!'].,0$```!`?Q#1#C$!`,`!3`]/___(4```40P!```$?HXQ`0```$
M!_$-$.,0$`P`%,#T___\=0``!2C`$```1]SC$!````0'\0T0XQ`0#``4P/3_
M__QE```%0,`0``!'T.,0$```!`?Q#1#C$!`,`!3`]/___%4```58P!```$?$
MXQ`0```$!_$-$.,0$`P`%,#T___\10``!7#K;_`P`"3C\/](_W'C,/"H`"3C
M0/"@`"10(/"T04#PH$$P\*A!(/"TP.7___YLQ$@``$?9Q"@``$?2N00`-,#E
M___]`<08``!'GI4`$`"G=``?P.7___W'Q"L``$@PN0(`(J=T``>G*0`!P.7_
M__Y[P.7___[8Q!@``$>9XR`0```6P.7___]/D@`J(<2X``!'CN,@L```%L#E
M____1)8")(KC(+```!;`Y?___SQ8$/"TE@$DBNPA``4`V+D4`"+K(@`#``W`
MY?___HWCL/"H``3C$+````3C$"```"3`$```'`?C$"`(`"180/"TQ!@``$>U
MXQ`@$``DN00`4L`0```;^>,0(!@`),0K``!'S\`0``!'RA)$Y4P0```$IR@`
M`1@4ISD``+GRT!*G.P`!IQ8`:.P4``0`V*=*``.Y%``1ZQ$``P`-XQ%?^/]Q
MIVD``.5($````+D4`$3`,```!'K$*```1ZO`Y?___-P8LA(BIW0`"<0H``!'
MH<#E___^$ABRQ"@``$>:P.7___U[P"```!JGP.4```&=N0(`(J=T`"'`$```
M1X;C$!````*G=``+P"```!IMP.4```&+Q"L``$=XP!```$=UXQ`0```"IX0`
M",0H``!';<#E```-$L0H``!':\#E___^S,#E___[>;D4`"OK;_#H``0'_NL#
M``,`#>PC``0`V+D$`&"Y%``BXP:P```$ZR(``P`-XP)?^/\DI_3_@P<'!P<'
M![D$`"_`,````!+C,#```!BG^_]@IPD``.,`\```),#T````"0<'!P<``(F(
M!P<'!T%`(`C$6```1I[K;_`P`"3C\/]8_W'$:```1HGE2/"@``#C,"`$`!3$
M*```1G3`Y?___0GK;_#8``0'_@<'!P?`$```1N#`(```1MVY(``2!X[$&```
M1G.Y`@`1!XX'\<`@``!&T,`0``!&S;D)`!+K(0`#``KK,0`_``RY"``RZS,`
M`0`*N0(`,P>.Q!@``$9NN0(`$0>.P"```$:T!_'`$```1K"5`!``!W[KK_!0
M`"3`$```1E/C\/]@_W'C$!````*GA``(Q"@``$9@P.7___SYP!```$1.P+``
M`$1/N00`H;D)`+'KNP`#``JGN___Q!@``$:+N2$`&Z=$`!S`Y?___Z#`$```
M1A7C$!````*GA``(P"```#AQP.7___LBP!```$9OD@$0`.NO\/``!`?^IQL`
M`<0;``!&:.L1``,`#>,1H```!`WAI_3_T^OO\'``)./P_V#_<>OO\1``!`?^
M!P<'!\`0``!%_.,0$````J>$`!3`,```1DS`(```.#WK[_!P`"3C\/]@_W'`
MY?___*CK[_$0``3`]/___V('!P<'!P?K[_!P`"3C\/]@_W'K[_$0``0'_@<'
M!P?K;_`P`"3C\/]@_W&Y`@!RIX0`3,08``!%ON.0$````J>$`$2Y!`!CN00`
M1^,00```E!(1IW0`+AM'N00`J;D4`(3CL*````*GA``>N00`2+D$`#?C(*``
M``3`Y?__^T,2(J=T`!]!&+``E3T0`*=T`!FY"0"I0;BP`>NJ``,`"E"@8`"Y
M!``KZV_PT``$!_ZG'@`]IX3_TD%`0`&G]/_(0:"@"*?T_\^GN0``I_3_[.OO
M\'``)+)/`!#K$0`@``VR3P`1X_#_4/]Q03#PI-('\*@0*,#E____EK)/`!#K
M$0`@``VR3P`1U0?PJ!`HIX0`!<#E___]5^OO\2``!`?^ZZ_P4``DLD\`$./P
M_U#_<>L1`"``#;D$`+*R3P`10:#PI-('\*@0*+D$`#JY!``KP.7___]HN0(`
M(J=T`!&R3P`0ZQ$`(``-LD\`$=4'\*@0**>$`!_`Y?___27C$/"D`!3$*```
M11?K$0`#``WC$"````CC(!`(``3C(!```"2Y`@`BIX3_TD$0$`BG]/_TZZ_Q
M```$!_[K;_`P`"2R3P`0X_#_4/]QZQ$`(``-LD\`$;D$`**Y!`"ST@?PJ!`H
ME3TP`*=T``1!L#`!IP@``+D$`!NGF0``LEX`D:<4__ZY"0";03#PI+D$`"K`
MY?___PJY`@`BIX0`,J<(``"G&0``N00`,K)>`!.G%/_^N0D`$KDA`!FG1`")
MIQD``.,QL```D$(Q(`"G&P`!N0(`,Z=T__>G*```LD\`$+D4`"+K$0`@``VR
M3P`1U0?PJ!`HIX0`R<#E___\IL08``!$F^-@$```!*<9```8@:<;``'K(0`#
M``WC(F_X_P*G=/_W["@``@#8P!```$3]N10`(N,0$```$NLB``,`#:>$`!>Y
M!``RN00`)L#E___Y',08``!$<>,@$```)+D"`"*G=``CIRC__Z?T_[G`$```
M1-OE3!````'`Y?__^>6Y`@!RIX3_\;D4`$BY!``VZT0``P`-P.7___GGQ!@`
M`$1,XW`0```DN10`&,0H``!$1.L1``,`#>,@(```!$$1(`CE2!````!0@/"D
MN00`&N,@$```E!(BIX0`!J<N`#VG=`!/N0D`&KD4`!'$B```1"3C</"D`!1!
M*1`"ZW<``P`-XW"````(P.7___F>XR!P```DN0(`(J>$_Z?C$/"D`!3C((``
M``3K$0`#``WC$2````3C(*```)!"(!``0:"@`;D$`#'`*P```/]!$!`!IX0`
M!J<N`#VG=/_NDCTP`*<I``#C,K```)!",A``IRL``;D"`#.G=/_WI_3_+T$0
M$`&G]/^GZV_PX``$!_X'!P<'!P?K?_`X`"2R3P`0X_#^R/]QZQ$`(``-LD\`
M$;D"`*+2!_$P$"BGA``BE0"@`*>$`![`Y?__^#"Y`@""IX0`%T%P\*"Y!``H
MP.7___CEN0(`(J=T`!NY!``HP.7___E\N00`*L#E___ZY[)/`!#K$0`@``VR
M3P`1U0?Q,!`HIX0`;<#E___[F$&P(!/`$```%K^G"```N00`*[)=`!*G%/_^
MIX3_T<`0```6Q[D$`"NR70`2IQ3__J>$_\:Y!``JIQD``+D$`#NR7@`2IQ3_
M_J<I``"Y"0`:LEX`(Z<4__ZY"0`K&A+L(0`"`-BY%``BP.7___CAN00`6[D$
M`)*Y!`!*P#```!:;P.7___L5N00`-[D$`"G`Y?__^LZG+O__N00`*:>$`!58
M$/"XP!L``/``IQY``*=T``S`Y?___V2Y!``IP.7___JGI_3_?<#E___XHJ?T
M__;K?_%P``0'_@<'LD\`$.L1`"``#;)/`!'KO_!8`"3C\/[(_W&Y!`"R03#P
MH-('\3`0*,#E___XU!(BIW0`+A@26"#PN,`K``#P`*<N0`"GA``'PBT``*``
MIW0`#J<Y``*Y!``KP.7___>[$!*G&O__B!``'[D4`"&R3P`0ZQ$`(``-LD\`
M$=4'\3`0**>$``G`Y?__^N6G&```I_3_[>N_\9``!`?^!P<'!^OO\'``),08
M``!"R>/P_V#_<>,@$```%L#E___Z?,!0```TE,1(``!"SL`P```6">OO\1``
M!,#T___Z30<'!P?K;_`P`"3C\/]8_W'$N```0J;C(+```!;`8```%T'`Y?__
M^EG`Y?___\[C(+```!;`Y?__^E"Y!`!6Y4CPH```P$````;8P#```!7IP.7_
M__=RZV_PV``$!_X'!P<'!P?K;_`P`"2R3P`0X_#_4/UQZQ$`(``-XR#PJ`)Q
MLD\`$=('(``0*$&P\*;`8```%=+`Y?__]Y#`0```%<ZY!`!2ISD0`;D$`"O`
MY?__]S2G+O__IW0`%J>Y``"R3P`0XR#PJ`)QZQ$`(``-LD\`$=4'(``0**>$
M`$O`Y?__^DP2(NP@$``@<:=$_^CCH/"G`7&G21``N00`.KD$`"O`Y?__^+JY
M!`"2$B*G1/_7IRH``;D4`"+`Y?__]ZZY`@"RIX3_S+D4`(FY(0"ZIZ0`!KGH
M@!NY84"AN2$`NJ?$``:YZ(`:N6%`L;D$`$BY!``Z[)`0`2!RN00`*\#E___Y
MW$$8L`"2`!``I_3_JKD$`"OK;_#@`@0'_@<'P/3___]T!P?K;_`P`"2R3P`0
MX_#^P/YQN00`LNL1`"``#>,@\3@!<;)/`!&Y!`"#T@<@`!`HP"```!5(P.7_
M__QFISD`+[D$`)*Y!``KP.7___@%N0(`(J>$`!RY!``[P"```!4XP.7___S%
MLD\`$.,@\3@!<>L1`"``#;)/`!'5!R``$"BGA`"RP.7___FWIP@``+D$`!NY
M!``HIZD``,`P```5'T&`\3BR7@"AIQ3__D%P\*@;J\#E___Y0*>J``&Y!`!2
MN0(`5:>$_\F5`%``P!```!2_N>*`4;D"`)FGA``:IP@``+D$`!6Y!``ILET`
M$J<4__ZG=``.P#```!3QIRD``,#E___Y&;D$`%*G]/_;IP@``*<9``"Y!``E
MLEX`$J<4__X;%;D4`"'C(E___W&5+R``IX0`(!H:IQX/_Z<D_XWCL/"@`"3`
M8```%,K`0```%32G.1``N00`*,#E___V'*<J``'"+P``$`"GQ``.I_0``:<:
M__^Y%``A02)0`)(`(`"G]/_1N00`-[D$`"C`Y?__^+(2(J=T_[!8$/#`P!L`
M`/``PAT``(``IW3_IJ<Y``&Y!``HP.7___7>$B*G=/^<N00`.,`@```4@L#E
M___\#[D$`"C`Y?__]NZY!`"RI_3_0[D$`"OK;_%P`00'_@<'N00`$N,P$```
ME!(S!XY!$!`!ISX`+[GB@"&G]/_U!P>Y`@`RIX0`!I4`,`"G=``(P"```!04
MP/3___;%N00`(Z<(``"G&0``LEX`$J<4__ZYZ3`AXT`?__]QN2$`-*<D``:G
M/___IW0`!*<I``&G)P`4N2``-*=T`"V5+S``IX3_V<`@```4,Z?T_]?C0$__
M_W&G]/_NE2]``*>$__FYZ3`4XR!/__]QN2$`,J<I``&YXC`2XU!```"0N00`
M)*=?`"_C0$___W&G=``ZN00`0KGI,!3C($___W&Y(0`RIR0`!J<___^G=``$
MIQD``>-`3___<:<7`"BY"0!#[!0``@#9PAX``!``IR0`)*=+``'`(```0/CK
M[_!P`"3C\/]@_W'L0!``(''`Y?__]OS`(```0.GK[_$0``0'_J<7_[RG]/^9
ME2]``*>$_].G]/_6IRD```?^!P>R3P`0ZQ$`(``-LD\`$>OO\'``)./P_S#_
M<<`@```3O-('\,@0*,`0```R#-(A\*80"L#E___ZZ\`@```3LL#E___ZY<`@
M```3L,#E___ZW\`@```3K\#E___ZV<`@```3K<#E___ZT\`@```3K\#E___Z
MS<`@```3@<#E___ZQ\`@```3J<#E___ZP<`@```3J,#E___ZN\`@```3I\#E
M___ZM<`@```3;L#E___ZK\`@```3H,#E___Z@;D"`#*GA``(P"```!.,P.7_
M__KKP"```!.9P.7___IQN0(`,J>$``C`(```$P_`Y?__^MO`(```$Y+`Y?__
M^F&Y`@`RIX0`(,`@```3.<#E___ZR\`P```3F<`@```34,#E___ZPK)/`!#K
M$0`@``VR3P`1U0?PR!`HIX0`)<#E___WM\`@```3<L#E___Z.;D"`#*GA``'
MP"```!,_I_3_V*=)``K`,```$VI!(/"WP.7___4^$B*G=/_.03#PP:?T_^SK
M[_%```0'_L0=```_J*<>__^G=``OZ^_P<``DP"```!,;X_#_8/]QP.7___H(
MN0(`(J>$`!OC$"```)"5`"``IX0`%,`7````,+D#`!'L$3^_`57$'P``/X+$
M+```/W_K[_$0``0'_J<8``"G]/_TQ"P``#]T!_[K[_!P`"3C\/]@_W'`Y?__
M]V+`Y?__]9^Y`@`BIX0`!>,@(```!.OO\1``!`?^!P?K;_`P`"2Y!`"RX_#_
M8/]QP"```!,&P.7___F]N00`.[D"`&*GA``&E0!@`*=T``O`(```$O;K;_#0
M``3`]/__^A[`Y?__]1^Y`@`BIW0`+*<(``"Y!``;N00`-K)>`"&G%/_^IQD`
M`+D)`"NR7@`3IQ3__KD)`!9!(A`"P.7___2"P#```!+@N00`HL!0```2;;D$
M`$O`Y?__]K6Y!``ZI_3_R.MO\-``!`?^!P<'!^MO\#``)+)/`!#K$0`@``VR
M3P`1X_#^&/=QN00`DN,@\>`(<=('(``0*,`0```^Z\`@```2-](/\+`0"-('
M\,`0&-(O\.`0(-(/\,@04-('\-@08,#E___Y1KD"`+*GA``BE0"P`*>$`![`
MY?___W.Y!``KP.7___2.N00`LK)/`!#C(/'@"''K$0`@``VR3P`1U0<@`!`H
MIX0"T\#E___VFL#E____/[D"`+*G=``G0:#PR.,0H````J=T``?`L```$E^G
M]``;XR"@```$P.7___D)N0(`$J=T``:GJP`(I_3_ZI4`$`"GA/_ZP.7___12
MN0(`LJ>$__.G"```N00`&Z<I``"R7@`AIQ3__KD)`"OK(@`!``VG*P`!P.7_
M__/:N00`<KD$`*+C0+```)021*=T`)%!L/#@XX"P```"IX0`'>,@L```!,#E
M___XR[D"`**GA`"0E0"@`*>$`(S`Y?__^Q`2(J>$`(:Y!``JP.7___00N00`
M@D&P\+"Y`@"(IW0`"^.@L````J>$``:5`*``IW0`=*<(``"Y!``8I[D``+)>
M`+&G%/_^N00`)Z<9``"Y"0"XLEX`$J<4__ZY"0`7&K&GN@0$N10`N[D$`"O`
MY?__\W_C</"@`"2Y!`"BP%```!%KN00`2,`P```1TL!@```1S,#E___UK*<Y
M`<"Y!``JP.7___5%IR[__Z=T`$K`Y?__]2Y88"``IVX`$:>$`$'$&```/;&Y
M%`!FN00`6N-`D```!,`P```1L.,@$```!,#E___TI:>Y``"G]/\7N00`*KD4
M`$3`,```$91!L+`!0:"@`L#E___U<Z?T_UVGNP`(I_3_8>,@L```!,#E___Z
M?Q(BIX0`";D$`"K`Y?__\W^Y!`""I[L`"*?T_V]!,/$0N00`*L#E___S4AAR
M$B*GA``5Q!@``#UGN00`6N-`D```!,`P```1AN,@$```!,#E___T7:?T_[A8
M$/$HP!L``/``IQY``*=T_^98@/$LP.7___5]&8*G=/_>6!#Q*,`;```!_Z<>
M`<"G=/_5N00`*\#E___RW+D$`++`(```$83`Y?__]]RY`@`BIW0`S>.`D```
M!*<(``"G&0``N00`*+)>`!*G%/_^N0D`&*<>``.GQ`!$N10`(>,RC_S_<<`@
M```19;)=`".G%/_^IW0`-J<>``2GA``-IQK__+D4`!'C$8___W&5+Q``IW0`
M)^,@D`@``J>$`"*G"```IQD``+D$`#*R7@`3IQ3__KD)`!+"'@````.GQ``1
MXR$O_/]QP!```!$WLET`$J<4__ZG=``%XX"0"``$P.7___UH$B*G=`#5ISD`
M`+D$`"C`Y?__\MZY!`"2&-(2(J>$`,BG20`"ISG_[L#E___Q\4%@\>"G20`&
MN00`-KD$`"G`Y?__\_:5`/'@IW0`8I5#\>&G=`!>E4'QXJ=T`%J50_'CIW0`
M5I5(\>2G=`!2E47QY:=T`$ZG20`"ISG_QKD$`"G`Y?__\<6G20`IN00`-KD$
M`"G`Y?__\\S`$```$3[`4```$!KC$/"@`"2Y!`!*P#```!#4N00`*\#E___T
M6;D$`"K`Y?__]`2Y!``[P"````_VP.7___>(N00`*\#E___]1Z?T_=OC@)``
M``3`Y?__\E^Y!``RN00`*,#E___Z@+D"`(*G=/\II_3_)*=)``"G.0``N00`
M*;D4`)W`Y?__\7?`Y0``#>"Y!`""I4^``+D$`#:Y!``IP.7___-Y$B*G)``K
MN00`*:=Y`!3`Y?__\T^Y!``X09#QHT&`\;>Y!``IN00`:,#E```.IN-`D```
MD+D$`"C`,```$!2GFP`!IXL``L#E___S\Z=W__&2`/'?I_3_@[D4`$*Y!``V
MN00`*,#E```-V*?T_\+`,```#^S`(```#['`Y?__]Q7`Y?__\3;`$```$*BY
M!`!BXQ#PH``DP%````]_N00`2L`P```01+D$`"O`Y?__\\&G.0'`N00`*\#E
M___S6J<N__^G=/]?P.7___-#6!`@`*<>`!&G=/]6IWH``<#E___Q",`0```0
M>N,0\*@`)+D$`&*Y%``7P%````]/XQ#PH``DN00`2L`P```0&+D$`"O`Y?__
M\XZG]/_-N00`*^MO\A@(!`?^!P<'!P<'ZV_P,``DX_#_8/]QQ*@``#NNXR"@
M```6P.7___-DN00`LN,@H```%L#E___S7-(`(+FPN,`@```/+<#E___V*[D"
M`"*GA``*E3$@`*=T``:5`"`!IX0`!<#E___[0,08```[A>,@$```%L#E___S
M.Z=9``NG20`!P#````_2P.7___&AN0(`(J=T`$W$J```.V[C(*```!;`Y?__
M\R2G60`#ITD``<`P```/OL#E___QBKD"`+*G=`"YQ)@``#M7XR"0```6P.7_
M__,-IUD``Z=)``'`,```#ZO`Y?__\7.Y`@"RIX0`[,`@```.N,#E___UT;D"
M`**GA`#%XR"0```6P.7___+OXQ"P$``$N00`2N,P$```!,#E___Q=*?T`,_C
M$"`0``2GN``!XW`0*``$Q(@``#L;[)O__P#86""``,:]```[D:>D`!2Y%@`B
MP.7___+(IUD``+D4`$FY!``WP.7___!?N0(`HJ=T`!'$'0``.WJG&O__&9&G
M=/^(I[@``<2H```Z\J?T`$;$*```.VVY%``;ZQ$``P`-XV$@```$XQ"@```$
M6"`0#,`K`"`$`*<N!`"G=``1XR`0$``$IP@``+)=`":G%/_^IW3_T:>Z``&G
M]/^QXR"````6P.7___*`IUD``J=)``#C,*````3`Y?__\K:G]/_DN18`(J>Z
M``'`Y?__\FVY!``WP.7__^\X6""@`,:]```[):=$_^^G]/\TXR"@```6P.7_
M__)9XQ"P$``$P$````[UXS`0```$P.7___#=XQ"P$``$XQ`0```$D4`0#:>$
M_R_C(*```!;`Y?__\CWC$+`0``3C,!````3`Y?__[^2G]/\>P.7___?WN0(`
MHN,@D```%J>$`&#`Y?__\B7C$+`0``2Y!`!*XS`0```$P.7___"JN00`*L#E
M___QU<2X```Z5N,@L```%L#E___R#+D$`*+C(+```!;`Y?__\@2G20`!P#``
M``ZEP.7__^[\P$````ZJN00`,KD$`"K`Y?__\(+C(+```!;`Y?__\>R2`""Y
MP"````V>P.7___2\Q"L``#JIN0(`(J=T`"/$*```.I[`Y?__^S_$*P``.IRY
M`@`BIW0`%L`@```.@<#E___O"L#E___QQ\0X```ZB.,0L!``!.-`,```!*?T
M_M2G.0'`Q"@``#I_P.7___%DN00`4J<N`!&GA``9[!(``0#8PA\````!I\0`
M$<08```Z9\1(```Z:.,P$```!,`@```.7\#E___NU^MO\-``!`?^ZZ_P4``D
MX_#_8/]QN00`LL#E___XZ,#E___XU;D$`*+`Y?__^D`2(J>$`!ZY`@"[IX0`
M&I4`L`"GA``6P#````V?N00`*L#E___OO;D@`**G=``*N00`*^NO\/``!,#T
M___UV>NO\/``!`?^!P<'![)/`!#K$0`@``VR3P`1ZV_P,``DIUD`"./P_-#_
M<:>Y``#2!_,H$"A!$/"HN00`,>-+(#@`!.L$`"``#.,`,```),!*`````.-`
M,`@`)*>[``BG.P`0IU?_[:=)`$#C,!!H``3C,!!``(+C,!`0`(+C,!```(+L
M4R"_(57L4R`^`5;C4!"``"2G&P`(IT?_Z>,0(!@`!.,0\*``).-0(```!.,0
M\*@`!,(:6H)YF>,0("``".,`(!``!..@(`@`!.Q%(+\E5>Q%(#H%5KD(`$'C
M$/"@``2YYQ`0N8``&N,0\*``@N.`\+``!+D(`$'"BEJ">9GK&@`"``SC@/"@
M``CL&@`A'E;CL/#```3L,2"_`%7"NEJ">9FYYS!PN8``=;F"`'"Y"`"'[)0@
MOP!5['0[OR55X]#PN``$['D`.@56PMI:@GF9N0@`>+D(`-#KA0`"``SLA0`A
M'E:Y@@`8N8``&;F"`!.Y"``[N0@`T>.P\,@`!,*Z6H)YF>QG(+\`5>Q((+\`
M5>P7.[\E5>P7&SH%5KD(`!WKV0`"``SLV0`A'E:Y@@"-N8``AKF"`(2Y"`!+
MX[#PT``$PKI:@GF9['$@OP!5[)T@OP!5N0@`@^PQ.[\E5>PQ&SH%5NL6``(`
M#+D(`#CL%@`A'E:Y!`!AN8(`UKF``->Y@@#9N0@`F^.P\-@`!,*Z6H)YF>R#
M(+\`5;D(`-3`&@````#L0SN_)57L0QLZ!5;K-P`"``RY"`!-[#<`(1Y6N00`
M<[F"`&>Y@`!HN8(`8;D(`!OCL/#@``3"NEJ">9GLU""_`%6Y"`!IP#H`````
M[)0[OR55[)0;.@56ZT@``@`,N0@`ENQ(`"$>5KD$`(2Y@@!XN8``?;F"`'.Y
M"``[X[#PZ``$PKI:@GF9[&D@OP!5N0@`<<!*`````.P9.[\E5>P9&SH%5NN=
M``(`#+D(`!?LG0`A'E:Y!`#9N8(`C;F``(:Y@@"$N0@`2^.P\/``!,*Z6H)Y
MF>QQ(+\`5;D(`(/`F@````#L,3N_)57L,1LZ!5;K%@`"``RY"``X[!8`(1Y6
MN00`8;F"`-:Y@`#7N8(`V;D(`)OCL/#X``3"NEJ">9GL@R"_`%6Y"`#4P!H`
M````[$,[OR55[$,;.@56ZS<``@`,N0@`3>PW`"$>5KD$`'.Y@@!GN8``:+F"
M`&&Y"``;X[#Q```$PKI:@GF9[-0@OP!5N0@`:<`Z`````.R4.[\E5>R4&SH%
M5NM(``(`#+D(`);L2``A'E:Y!`"$N8(`>+F``'VY@@!SN0@`.^.P\0@`!,*Z
M6H)YF>QI(+\`5;D(`''`2@````#L&3N_)57L&1LZ!5;KG0`"``RY"``7[)T`
M(1Y6N00`V;F"`(VY@`"&N8(`A+D(`$NY"`"#X[#Q$``$PKI:@GF9['$@OP!5
MP)H`````[#$[OR55[#$;.@56ZQ8``@`,N0@`..P6`"$>5NR#(+\`5;D$`&&Y
M@@#6N8``U[F"`-FY"`";N0@`U..P\1@`!.Q#.[\E5<*Z6H)YF>Q#&SH%5KD(
M`$W`&@````#LU""_`%7K-P`"``SL-P`A'E:Y!`!SP#H`````N8(`9[F``&BY
M@@!AN0@`&[D(`&GCL/$@``3LE#N_)57"NEJ">9GLE!LZ!5;K2``"``RY"`"6
M[$@`(1Y6N00`A+F"`'BY@`!]N8(`<[D(`#OL:2"_`%6Y"`!QP$H`````[!D[
MOR55X[#Q*``$[!D;.@56PKI:@GF9N0@`%^N=``(`#.R=`"$>5KF"`(FY@`"&
MN8(`A+D(`$NY"`"#[#$[OR55[#$;.@56N0@`..QQ(+\`5>R#(+\`5>S9(+\`
M5>L6``(`#..P\3``!.P6`"$>5L*Z6H)YF>QA(+\`5;F"`)&Y@`"7N8(`G;D(
M`-NY"`"4[$,[OR55[$,;.@56ZS<``@`,[#<`(1Y6N8(`$[F``!BY@@`6N0@`
M';D(`$GL<R"_`%7LE""_`%7LU#N_)57CL/$X``3LU!LZ!5;"NEJ">9FY"`#1
MN0@`:^L8``(`#.P8`"$>5KF"`#&Y@``YN8(`-[D(`#;L32"_`%7L@2"_`%7L
M;3N_)57L;2`Z!5:Y"`!CZSD``@`,[#D`(1Y6XY#Q0``$N8(`$\*:6H)YF;F`
M`!2Y"`!YN8(`&+D(`!?KE``"``SL=CN_)57LE``A'E;L=B`Z!5:YYY!#N0@`
M<;F"`$;C$/%(``3"&F[9ZZ&Y"``8N1H`%.R'.[\E5>R'(#H%5KD(`('L%B*_
M/E7L%@(A'E:Y!`!AXT#Q6``$XQ#Q4``$PAINV>NAN1H`$[GG8#FY@@`WN1H`
M$[D$`#'L&#N_)57L&"`Z!5:Y"``3[#<BOSY5[#<"(1Y6PDINV>NAN00`<[D:
M`$FYYS`VN8(`..R8(K\^5;D:`$/LF`(A'E:Y!``TN>>0A[F"`('L03N_)57L
M02`Z!5:Y"`!#XS#Q8``$PCINV>NAN1H`-KD:`#BY!`"#[#0[OR55[#0@.@56
MN0@`..R!(K\^5>R!`B$>5N,0\6@`!,(:;MGKH;D:`!>YYX!YN8(`=+D:`!>Y
M!`!Q[!,[OR55[!,@.@56N0@`%^QT(K\^5>QT`B$>5N-`\7``!,)*;MGKH;D:
M`$FYYW"8N8(`D[D:`$FY!`"4[$$[OR55[$$@.@56N0@`2>R3(K\^5>R3`B$>
M5N,P\7@`!,(Z;MGKH;D:`#BYYY"'N8(`@;D:`#BY!`"#[#0[OR55[#0@.@56
MN0@`..R!(K\^5>R!`B$>5N,0\8``!,(:;MGKH;D:`!>YYX!YN8(`=+D:`!>Y
M!`!Q[!,[OR55[!,@.@56N0@`%^QT(K\^5>QT`B$>5N-`\8@`!,)*;MGKH;D:
M`$FYYW"8N8(`D[D:`$FY!`"4[$$[OR55[$$@.@56N0@`2>R3(K\^5>R3`B$>
M5N,P\9``!,(Z;MGKH;D:`#BYYY"'N8(`@;D:`#BY!`"#[#0[OR55[#0@.@56
MN0@`..R!(K\^5>R!`B$>5N,0\9@`!,(:;MGKH;D:`!>YYX!YN8(`=+D:`!>Y
M!`!Q[!,[OR55[!,@.@56N0@`%^QT(K\^5>QT`B$>5N-`\:``!,)*;MGKH;D:
M`$FYYW"8N8(`D[D:`$FY!`"4[$$[OR55[$$@.@56N0@`2>R3(K\^5>R3`B$>
M5N,P\:@`!,(Z;MGKH;D:`#BYYY"'N8(`@;D:`#BY!`"#[#0[OR55[#0@.@56
MN0@`..R!(K\^5>R!`B$>5N,0\;``!,(:;MGKH;D:`!>YYX!YN8(`=+D:`!>Y
M!`!Q[!,[OR55[!,@.@56N0@`%^QT(K\^5>QT`B$>5N-`\;@`!,)*;MGKH;D:
M`$FYYW"8N8(`D[D:`$FY!`"4[$$[OR55[$$@.@56N0@`2>R3(K\^5>R3`B$>
M5N,P\<``!,(Z;MGKH;D:`#BYYY"'N8(`@;D:`#BY!`"#[#0[OR55[#0@.@56
MN0@`..R!(K\^5>R!`B$>5N,0\<@`!,(:;MGKH;D:`!>YYX!YN8(`=+D:`!>Y
M!`!Q[!,[OR55[!,@.@56N0@`%^QT(K\^5>S1(K\^5>QT`B$>5NS1`B$>5N-`
M\=``!,)*;MGKH;D:`$FYYW"8N8(`D[D:`$GL8R*_/E6Y!`"4[&,"(1Y6[$$[
MOR55XS#QV``$[$$@.@56PCINV>NAN1H`.+GG8(>Y@@"!N00`';D:`#CCT/'@
M``3"VF[9ZZ&Y&@#7N0@`2;D$`(/LE""_`%7L-#N_)56Y!`!][#D`.@56N><0
MUKD(`#BY@@!-[(,@OP!5N1H`=.Q#.[\E5>Q#&SH%5NLY``(`#.PY`"$>5NR3
M(+\`5;GF,-&YY)"QN8``V+F!`-NY"`!'X[#QZ``$PKJ/&[S<N1H`MKD$`&NY
M"`!M[-0[OR55[-0;.@56['0@OP!5N>C01NO8``(`#.S8`"$>5KD$`(VYYM#3
MN>20.+F``->Y@0#3XS#Q\``$PCJ/&[S<N1H`,>L7``(`#+D(`-/L%P`A'E;L
M<2"_`%6YY'"X[&0@OP!5[#0[OR55[#0;.@56N0@`/;GF$-BY@`#6N8$`V^.P
M\?@`!,*ZCQN\W+D(`)NY"`#9[$,@OP!5[),[OR55[),;.@56N0@`G>O6``(`
M#.S6`"$>5KF!`!VY@``4N00`;;F``->Y@0#1XQ#R```$PAJ/&[S<N1H`&+D(
M`!WL.2"_`%7LB3N_)57LB1LZ!5:YZ("1ZQ0``@`,[!0`(1Y6[$$@OP!5N>1`
MMKGF$-:Y@`#3N8$`V^.P\@@`!,*ZCQN\W+D(`'NY"`#7[(D@OP!5['D[OR55
M['D;.@56N0@`?>O3``(`#.S3`"$>5KF!`!VY@``8N00`/;F``-2Y@0#1XQ#R
M$``$PAJ/&[S<N1H`%NQG.[\E5>QG&SH%5NR7(+\`5;D(`!VYZ&!Q[&<@OP!5
MZQ@``@`,[!@`(1Y6[($@OP!5N>2`L[GF$-.Y@`#9N8$`V^.P\A@`!,*ZCQN\
MW+D(`$NY"`#4[$<[OR55[$<;.@56N0@`3>O9``(`#.S9`"$>5KF!`!VY@``6
MN00`G;F``-BY@0#1XQ#R(``$PAJ/&[S<N1H`$[D(`-'L=""_`%7K%@`"``SL
M%@`A'E;L82"_`%6YY&"Y[#0[OR55[#0;.@56N0@`/;GF$-FY@`#7N8$`V^.P
M\B@`!,*ZCQN\W+D(`(NY"`#8[$,@OP!5[(,[OR55[(,;.@56N0@`C>O7``(`
M#.S7`"$>5KF!`!VY@``4N00`?;F``-:Y@0#1XQ#R,``$PAJ/&[S<N1H`&;D(
M`-'L.""_`%7K%``"``SL%``A'E;L02"_`%6YY$"W[)@[OR55[)@;.@56N0@`
MG;GF$->Y@`#3N8$`V^.P\C@`!,*ZCQN\W+D(`&NY"`#6[(D@OP!5[&D[OR55
M[&D;.@56N0@`;>O3``(`#.S3`"$>5KF!`!VY@``8N00`/;F``-2Y@0#1XQ#R
M0``$PAJ/&[S<N1H`%[D(`-'LEB"_`%7K&``"``SL&``A'E;L@2"_`%6YY("S
M['8[OR55['8;.@56N0@`?;GF$-.Y@`#9N8$`V^.P\D@`!,*ZCQN\W+D(`$NY
M"`#4[&<@OP!5[$<[OR55[$<;.@56N0@`3>O9``(`#.S9`"$>5KF!`!VY@``6
MN00`G;F``-BY@0#1XQ#R4``$PAJ/&[S<N1H`$[D(`-'L=""_`%7K%@`"``SL
M%@`A'E;L82"_`%6YY&"Y[#0[OR55[#0;.@56N0@`/;GF$-FY@`#7N8$`V^.P
M\E@`!,*ZCQN\W+D(`(NY"`#8[$,@OP!5[(,[OR55[(,;.@56N0@`C>O7``(`
M#.S7`"$>5KF!`!VY@``4N00`?;F``-:Y@0#1XQ#R8``$PAJ/&[S<N1H`&;D(
M`-'L.""_`%7K%``"``SL%``A'E;L02"_`%6YY$"W[)@[OR55[)@;.@56N0@`
MG;GF$->Y@`#3N8$`V^.P\F@`!,*ZCQN\W+D(`&NY"`#6[(D@OP!5[&D[OR55
M[&D;.@56N0@`;>O3``(`#.S3`"$>5KD$`#VYYM#1N>1`$[F``-BY@0#1XQ#R
M<``$PAJ/&[S<N1H`%^R6(+\`5;D(`-'L%CN_)57L%ALZ!5;K:``"``SL:``A
M'E;LAB"_`%6YY("SN0@`';GF8-.Y@`#9N8$`V^.P\G@`!,*ZCQN\W+D(`$OL
M<2"_`%6Y"`#4[$$[OR55[$$@.@56ZQD``@`,[!D`(1Y6N8$`8;F``&>Y!`"1
MN8``&+F!`!;C8/*```3":H\;O-RY&@!CZS<``@`,N0@`8>PW`"$>5KD(`$VY
M!`!S[!0[OR55[!0@.@56N0@`%KGG,&GC,/*(``2Y@@!DPCK*8L'6N0@`.+D:
M`#;L@3N_)57L9"*_/E7L@2`Z!5;L9`(A'E:Y"`"#N>=@U^,P\I``!+F"`-'"
M.LIBP=:Y&@`Y[)$BOSY5N1H`/>R1`B$>5KD$`$.YYY`6N8(`&.PX.[\E5>PX
M(#H%5KD(`#3C0/*8``3"2LIBP=:Y&@!'N1H`0;D$`!3CL/"@``3L0SN_)57L
M0R`Z!5:Y"`!![!@BOSY5[!@"(1Y6N00`@;GG@'FY@@!SXQ#RH``$PAK*8L'6
MN1H`%KD:`!>Y!`!Q[!0[OR55[!0@.@56N0@`%^QS(K\^5>QS`B$>5N,P\J@`
M!,(ZRF+!UKD:`#FYYW"8N8(`E+D:`#FY!`"3[#$[OR55[#$@.@56N0@`.>R4
M(K\^5>R4`B$>5N-`\K``!,)*RF+!UKD:`$BYYY"'N8(`@;D:`$BY!`"$[$,[
MOR55[$,@.@56N0@`2.R!(K\^5>R!`B$>5N,0\K@`!,(:RF+!UKD:`!>YYX!Y
MN8(`<[D:`!>Y!`!Q[!0[OR55[!0@.@56N0@`%^QS(K\^5>QS`B$>5N,P\L``
M!,(ZRF+!UKD:`#FYYW"8N8(`E+D:`#FY!`"3[#$[OR55[#$@.@56N0@`.>R4
M(K\^5>R4`B$>5N-`\L@`!,)*RF+!UKD:`$BYYY"'N8(`@;D:`$BY!`"$[$,[
MOR55[$,@.@56N0@`2.R!(K\^5>R!`B$>5N,0\M``!,(:RF+!UKD:`!>YYX!Y
MN8(`<[D:`!>Y!`!Q[!0[OR55[!0@.@56N0@`%^QS(K\^5>QS`B$>5N,P\M@`
M!,(ZRF+!UKD:`#FYYW"8N8(`E+D:`#FY!`"3[#$[OR55[#$@.@56N0@`.>R4
M(K\^5>R4`B$>5N-`\N``!,)*RF+!UKD:`$BYYY"'N8(`@;D:`$BY!`"$[$,[
MOR55[$,@.@56N0@`2.R!(K\^5>R!`B$>5N,0\N@`!,(:RF+!UKD:`!>YYX!Y
MN8(`<[D:`!>Y!`!Q[!0[OR55[!0@.@56N0@`%^QS(K\^5>QS`B$>5N,P\O``
M!,(ZRF+!UKD:`#FYYW"8N8(`E+D:`#FY!`"3[#$[OR55[#$@.@56N0@`.>R4
M(K\^5>R4`B$>5N-`\O@`!,)*RF+!UKD:`$BYYY"'N8(`@;D:`$BY!`"$[$,[
MOR55[$,@.@56N0@`2.R!(K\^5>R!`B$>5N,0\P``!,(:RF+!UKD:`!>YYX!Y
MN8(`<[D:`!>Y!`!Q[!0[OR55[!0@.@56N0@`%^QS(K\^5>QS`B$>5N,P\P@`
M!,(ZRF+!UKD:`#FYYW"8N8(`E+D:`#FY!`"3[&$BOSY5[#$[OR55[&$"(1Y6
M[#$@.@56N0@`.>R4(K\^5>R4`B$>5N-`\Q``!,)*RF+!UKD:`$BYYY"'N8(`
M@>,0\Q@`!,(:RF+!UKD:`!>YYV!YN8(`<[D:`$BY&@`7N00`A+D$`''L0SN_
M)57L0R`Z!5:Y"`!([(0@OP!5[!0[OR55[!@`.@56N0@`%^QS(K\^5>QS`B$>
M5N,P\R``!,(ZRF+!UKD(`#6YYW!6N1H`.;F"`$6Y&@`TN0@`H>-@("``"+D$
M`%/`J@````#CH"`(`"3L,3N_)56Y"`"W[#$;.@56P+H`````X[`@&``DN0@`
M-<!J`````.-@("``),`Z`````.,P(```).L8``(`#.P8`"$>5KD(``'`"@``
M``#C`"`0`"2R3P`0ZQ$`(``-LD\`$=4'\R@0**>$``7`Y?__YHWK;_-@``0'
M_@<'!P?K[_!P`"2G*0"`X_#_8/]QP.7__^/\P#%G12,!XS`@```DY4@@*```
MP#_OS:N)XS`@"``DY4@@,```P#^8NMS^XS`@$``DY4P@>```P#$0,E1VXS`@
M&``DP#_#TN'PXS`@(``DZ^_Q$``$!_X'!P<'ZV_P,``DZQ0``P`-N00`HKD$
M`+3C("`H``2Y"``2[$$@OP!5X_#_8/]QN3$`(:?$``7K`:`P`'KC0*`H`"3K
M&P`=``SC$*`P``CC$*`P`"1!D*`XXQ"@>``2IX0`-*>(`$`;@1F+N00`*;GR
ML(NY&``AN10`2+DA`".GI``&N>A`$KEA0#&YZ$!SN2$`(Z?$``2Y84`GP.7_
M_^71&!A:$*!X4!"@>*<>`$"G=``SN00`*ANXP.7___1*N10`N[D$`#?KBP`&
M`-ZGB@`!IQ@``1*[06"@>+GR4(&GA@`AN2$`.:?$``:YZ+`9N6%`,;DA`#FG
MI``&N>BP$[EA0)&Y!`!+N00`*<#E___EF5"PH'CK;_#0``0'_J?T``&Y(0`Y
MI\0`!KDA`#:G1/_XN2$`.4%P,$"GI``&N2$`EZ=$_^ZY!``JI[K_P+D4`+O2
M/Y``,`#`Y?__\_NY!``WI_3_O^N/\$``)+D$`*+CD#`H``3C@#`P``3L*3J_
M/57L$@`!`-BY%``B02(P.)*`(`#C\/]@_W&Y%``AN00`LT%",#BG'@`XI\0`
M6*<H`$"G60``N?D0$KD$`"2Y%@`QITD``*@D``"G%/_^N00`*\#E___SOM<W
ML#BP..L8`!@`#$(0L'!"@+!SZQ@`$``,0A"P<4*0L'?K&``(``Q"$+!RN00`
M*^L9`!@`#$(0L'3K&0`0``Q"$+!UZQD`"``,0A"P=L#E___SE+D$`"O2`Z``
ML`32`Z`$L`S2`Z`(L!32`Z`,L!S2`Z`0L"3KC_#@``3`]/__Y)6G*``XIUD`
M`+GY$!*Y!``DN18`,:=)``"H)```IQ3__J?T_[+KO_!8`"3C\/]@_W'`L```
M*PKC$+````2G'___IW0`!NN_\/@`!`?^X["_^/]Q#>&G]/_Q!P<'!^OO\'``
M)./P_V#_<>OO\1``!`?^!P<'!^OO\'``)+D$``^G^_]@XP#P```DP.7__^9^
MZ^_Q$``$!_XO=&UP```N`%!!4E]435!$25(``%1%35!$25(`5$U0`%5315(`
M`%5315).04U%```N+@``)7,O)7,`1'EN84QO861E<CHZ8F]O=%]$>6YA3&]A
M9&5R`$EN=&5R;F%L<SHZ4$%2.CI"3T]4``!E>&4`+W!R;V,O)6DO)7,`4$%2
M7U1%35```%!!4E]04D]'3D%-10``.@`O`%!%4DPU3$E"``!015),3$E"`%!%
M4DPU3U!4``!015),24\``%!!4E])3DE424%,25I%1`!005)?4U!!5TY%1`!0
M05)?0TQ%04X`4$%27T1%0E5'`%!!4E]#04-(10!005)?1TQ/0D%,7T1%0E5'
M``!005)?1TQ/0D%,7U1-4$1)4@!005)?1TQ/0D%,7U1%35``4$%27T=,3T)!
M3%]#3$5!3@``4$%27T-,14%./0``,0!,1%],24)205)97U!!5$@`4UE35$5-
M```E,#)X``!P87(M```E<R5S)7,E<P``)7,Z(&-R96%T:6]N(&]F('!R:79A
M=&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI"@``)7,Z('!R
M:79A=&4@<W5B9&ER96-T;W)Y("5S(&ES('5N<V%F92`H<&QE87-E(')E;6]V
M92!I="!A;F0@<F5T<GD@>6]U<B!O<&5R871I;VXI"@``4$%42```<&%R;```
M+G!A<@``)7,E<V-A8VAE+25S)7,``"5S)7-T96UP+25U)7,`)7,E<W1E;7`M
M)74M)74E<P``05)'5@``&`!P97)L```P`%!!4CHZ4&%C:V5R.CI615)324].
M```Q+C`T.0!5;F%B;&4@=&\@8W)E871E(&-A8VAE(&1I<F5C=&]R>0``)7,Z
M(&-R96%T:6]N(&]F('!R:79A=&4@8V%C:&4@<W5B9&ER96-T;W)Y("5S(&9A
M:6QE9"`H97)R;F\])6DI"@``+64``"TM``!E=F%L("=E>&5C("]U<W(O8FEN
M+W!E<FP@("U3("0P("1[,2LB)$`B?2<*:68@,#L@(R!N;W0@<G5N;FEN9R!U
M;F1E<B!S;VUE('-H96QL"G!A8VMA9V4@7U]P87)?<&P["FUY("@D4$%27TU!
M1TE#+"`D<&%R7W1E;7`L("1P<F]G;F%M92P@0'1M<&9I;&4I.PI%3D0@>R!I
M9B`H)$5.5GM005)?0TQ%04Y]*2!["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q
M=6ER92!&:6QE.CI"87-E;F%M93L*<F5Q=6ER92!&:6QE.CI3<&5C.PIM>2`D
M=&]P9&ER(#T@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'!A<E]T96UP*3L*
M;W5T<RAQ<7M296UO=FEN9R!F:6QE<R!I;B`B)'!A<E]T96UP(GTI.PI&:6QE
M.CI&:6YD.CIF:6YD9&5P=&@H<W5B('L@*"`M9"`I(#\@<FUD:7(@.B!U;FQI
M;FL@?2P@)'!A<E]T96UP*3L*<FUD:7(@)'!A<E]T96UP.PII9B`H+60@)'!A
M<E]T96UP("8F("1>3R!N92`G35-7:6XS,B<I('L*;7D@)'1M<"`](&YE=R!&
M:6QE.CI496UP*`I414U03$%412`]/B`G=&UP6%A86%@G+`I$25(@/3X@1FEL
M93HZ0F%S96YA;64Z.F1I<FYA;64H)'1O<&1I<BDL"E-51D9)6"`]/B`G+F-M
M9"<L"E5.3$E.2R`]/B`P+`HI.PIP<FEN="`D=&UP("(C(2]B:6XO<V@*>#TQ
M.R!W:&EL92!;(%PD>"`M;'0@,3`@73L@9&\*<FT@+7)F("<D<&%R7W1E;7`G
M"FEF(%L@7"$@+60@)R1P87)?=&5M<"<@73L@=&AE;@IB<F5A:PIF:0IS;&5E
M<"`Q"G@]8&5X<'(@7"1X("L@,6`*9&]N90IR;2`G(B`N("1T;7`M/F9I;&5N
M86UE("X@(B<*(CL*8VAM;V0@,#<P,"PD=&UP+3YF:6QE;F%M93L*;7D@)&-M
M9"`]("1T;7`M/F9I;&5N86UE("X@)R`^+V1E=B]N=6QL(#(^)C$@)B<["F-L
M;W-E("1T;7`["G-Y<W1E;2@D8VUD*3L*;W5T<RAQ<2A3<&%W;F5D(&)A8VMG
M<F]U;F0@<')O8V5S<R!T;R!P97)F;W)M(&-L96%N=7`Z("D*+B`D=&UP+3YF
M:6QE;F%M92D["GT*?2!]"D)%1TE.('L*26YT97)N86QS.CI005(Z.D)/3U0H
M*2!I9B!D969I;F5D("9);G1E<FYA;',Z.E!!4CHZ0D]/5#L*)%!!4E]-04=)
M0R`](")<;E!!4BYP;5QN(CL*979A;"!["E]P87)?:6YI=%]E;G8H*3L*;7D@
M)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*;7D@)4-O;F9I9R`]("@*<&%T
M:%]S97`@("`@/3X@*"1>3R`]?B`O7DU35VEN+R`_("<[)R`Z("<Z)RDL"E]E
M>&4@("`@("`@(#T^("@D7D\@/7X@+UXH/SI-4U=I;GQ/4S)\8WEG=VEN*2\@
M/R`G+F5X92<@.B`G)RDL"E]D96QI;2`@("`@(#T^("@D7D\@/7X@+UY-4U=I
M;GQ/4S(O(#\@)UQ<)R`Z("<O)RDL"BD["E]S971?<')O9VYA;64H*3L*7W-E
M=%]P87)?=&5M<"@I.PIM>2`H)'-T87)T7W!O<RP@)&1A=&%?<&]S*3L*>PIL
M;V-A;"`D4TE'>U]?5T%23E]??2`]('-U8B![?3L*;W!E;B!?1D@L("<\)RP@
M)'!R;V=N86UE(&]R(&QA<W0["F)I;FUO9&4H7T9(*3L*;7D@)&)U9CL*;7D@
M)'-I>F4@/2`M<R`D<')O9VYA;64["FUY("1C:'5N:U]S:7IE(#T@-C0@*B`Q
M,#(T.PIM>2`D;6%G:6-?<&]S.PII9B`H)'-I>F4@/#T@)&-H=6YK7W-I>F4I
M('L*)&UA9VEC7W!O<R`](#`["GT@96QS:68@*"AM>2`D;2`]("1S:7IE("4@
M)&-H=6YK7W-I>F4I(#X@,"D@>PHD;6%G:6-?<&]S(#T@)'-I>F4@+2`D;3L*
M?2!E;'-E('L*)&UA9VEC7W!O<R`]("1S:7IE("T@)&-H=6YK7W-I>F4["GT*
M=VAI;&4@*"1M86=I8U]P;W,@/CT@,"D@>PIS965K*%]&2"P@)&UA9VEC7W!O
M<RP@,"D["G)E860H7T9(+"`D8G5F+"`D8VAU;FM?<VEZ92`K(&QE;F=T:"@D
M4$%27TU!1TE#*2D["FEF("@H;7D@)&D@/2!R:6YD97@H)&)U9BP@)%!!4E]-
M04=)0RDI(#X](#`I('L*)&UA9VEC7W!O<R`K/2`D:3L*;&%S=#L*?0HD;6%G
M:6-?<&]S("T]("1C:'5N:U]S:7IE.PI]"FQA<W0@:68@)&UA9VEC7W!O<R`\
M(#`["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@-"P@,#L*<F5A9"!?1D@L("1B
M=68L(#0["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@-"`M('5N<&%C:R@B3B(L
M("1B=68I+"`P.PHD9&%T85]P;W,@/2!T96QL(%]&2#L*;7D@)7)E<75I<F5?
M;&ES=#L*<F5A9"!?1D@L("1B=68L(#0[("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(R!R96%D('1H92!F:7)S="`B1DE,12(*=VAI;&4@*"1B=68@97$@
M(D9)3$4B*2!["G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@
M=6YP86-K*").(BP@)&)U9BD["FUY("1F=6QL;F%M92`]("1B=68["F]U=',H
M<7$H56YP86-K:6YG(&9I;&4@(B1F=6QL;F%M92(N+BXI*3L*;7D@)&-R8R`]
M("@@)&9U;&QN86UE(#U^('-\7BA;82UF7&1=>SA]*2]\?"`I(#\@)#$@.B!U
M;F1E9CL*;7D@*"1B87-E;F%M92P@)&5X="D@/2`H)&)U9B`]?B!M?"@_.BXJ
M+RD_*"XJ*2A<+BXJ*7PI.PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L
M("1B=68L('5N<&%C:R@B3B(L("1B=68I.PII9B`H9&5F:6YE9"@D97AT*2!A
M;F0@)&5X="`A?B`O7"XH/SIP;7QP;'QI>'QA;"DD+VDI('L*;7D@)&9I;&5N
M86UE(#T@7W1E;7!F:6QE*"(D8W)C)&5X="(L("1B=68L(#`W-34I.PHD4$%2
M.CI(96%V>3HZ1G5L;$-A8VAE>R1F=6QL;F%M97T@/2`D9FEL96YA;64["B10
M05(Z.DAE879Y.CI&=6QL0V%C:&5[)&9I;&5N86UE?2`]("1F=6QL;F%M93L*
M?0IE;'-I9B`H("1F=6QL;F%M92`]?B!M?%XO/W-H;&EB+WP@86YD(&1E9FEN
M960@)$5.5GM005)?5$5-4'T@*2!["FUY("1F:6QE;F%M92`](%]T96UP9FEL
M92@B)&)A<V5N86UE)&5X="(L("1B=68L(#`W-34I.PIO=71S*")32$Q)0CH@
M)&9I;&5N86UE7&XB*3L*?0IE;'-E('L*)')E<75I<F5?;&ES='LD9G5L;&YA
M;65](#T*)%!!4CHZ2&5A=GDZ.DUO9'5L94-A8VAE>R1F=6QL;F%M97T@/2![
M"F)U9B`]/B`D8G5F+`IC<F,@/3X@)&-R8RP*;F%M92`]/B`D9G5L;&YA;64L
M"GT["GT*<F5A9"!?1D@L("1B=68L(#0["GT*;&]C86P@0$E.0R`]("AS=6(@
M>PIM>2`H)'-E;&8L("1M;V1U;&4I(#T@0%\["G)E='5R;B!I9B!R968@)&UO
M9'5L92!O<B`A)&UO9'5L93L*;7D@)&EN9F\@/2!D96QE=&4@)')E<75I<F5?
M;&ES='LD;6]D=6QE?2!O<B!R971U<FX["B1)3D-[)&UO9'5L97T@/2`B+VQO
M861E<B\D:6YF;R\D;6]D=6QE(CL*:68@*"1%3E9[4$%27T-,14%.?2!A;F0@
M9&5F:6YE9"@F24\Z.D9I;&4Z.FYE=RDI('L*;7D@)&9H(#T@24\Z.D9I;&4M
M/FYE=U]T;7!F:6QE(&]R(&1I92`D(3L*8FEN;6]D92@D9F@I.PIP<FEN="`D
M9F@@)&EN9F\M/GMB=69].PIS965K*"1F:"P@,"P@,"D["G)E='5R;B`D9F@[
M"GT*96QS92!["FUY("1F:6QE;F%M92`](%]T96UP9FEL92@B)&EN9F\M/GMC
M<F-]+G!M(BP@)&EN9F\M/GMB=69]*3L*;W!E;B!M>2`D9F@L("<\)RP@)&9I
M;&5N86UE(&]R(&1I92`B8V%N)W0@<F5A9"`D9FEL96YA;64Z("0A(CL*8FEN
M;6]D92@D9F@I.PIR971U<FX@)&9H.PI]"F1I92`B0F]O='-T<F%P<&EN9R!F
M86EL960Z(&-A;FYO="!F:6YD("1M;V1U;&4A7&XB.PI]+"!`24Y#*3L*<F5Q
M=6ER92!84TQO861E<CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E($-A
M<G`Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R.CI(96%V>3L*4$%2.CI(96%V
M>3HZ7VEN:71?9'EN86QO861E<B@I.PIR97%U:7)E($E/.CI&:6QE.PIW:&EL
M92`H;7D@)&9I;&5N86UE(#T@*'-O<G0@:V5Y<R`E<F5Q=6ER95]L:7-T*5LP
M72D@>PIU;FQE<W,@*"1)3D-[)&9I;&5N86UE?2!O<B`D9FEL96YA;64@/7X@
M+T)31%!!3B\I('L*:68@*"1F:6QE;F%M92`]?B`O7"YP;6,_)"]I*2!["G)E
M<75I<F4@)&9I;&5N86UE.PI]"F5L<V4@>PID;R`D9FEL96YA;64@=6YL97-S
M("1F:6QE;F%M92`]?B`O<VET96-U<W1O;6EZ95PN<&PD+SL*?0I]"F1E;&5T
M92`D<F5Q=6ER95]L:7-T>R1F:6QE;F%M97T["GT*;&%S="!U;FQE<W,@)&)U
M9B!E<2`B4$M<,#`S7#`P-"(["B1S=&%R=%]P;W,@/2`H=&5L;"!?1D@I("T@
M-#L@("`@("`@("`@("`@("`@(R!S=&%R="!O9B!Z:7`*?0IM>2!`<&%R7V%R
M9W,["FUY("@D;W5T+"`D8G5N9&QE+"`D;&]G9F@L("1C86-H95]N86UE*3L*
M9&5L971E("1%3E9[4$%27T%04%]2155317T[(",@<V%N:71I>F4@*%)%55-%
M(&UA>2!B92!A('-E8W5R:71Y('!R;V)L96TI"B1Q=6EE="`](#`@=6YL97-S
M("1%3E9[4$%27T1%0E5'?3L*:68@*"$D<W1A<G1?<&]S(&]R("@D05)'5ELP
M72!E<2`G+2UP87(M;W!T:6]N<R<@)B8@<VAI9G0I*2!["FUY("5D:7-T7V-M
M9"`]('%W*`IP("`@8FQI8E]T;U]P87(*:2`@(&EN<W1A;&Q?<&%R"G4@("!U
M;FEN<W1A;&Q?<&%R"G,@("!S:6=N7W!A<@IV("`@=F5R:69Y7W!A<@HI.PII
M9B`H0$%21U8@86YD("1!4D=66S!=(&5Q("<M+7)E=7-E)RD@>PIS:&EF="!`
M05)'5CL*)$5.5GM005)?05!07U)%55-%?2`]('-H:69T($!!4D=6.PI]"F5L
M<V4@>R`C(&YO<FUA;"!P87)L(&)E:&%V:6]U<@IM>2!`861D7W1O7VEN8SL*
M=VAI;&4@*$!!4D=6*2!["B1!4D=66S!=(#U^("]>+2A;04E-3T),8G%P:75S
M5'9=*2@N*BDO(&]R(&QA<W0["FEF("@D,2!E<2`G22<I('L*<'5S:"!`861D
M7W1O7VEN8RP@)#(["GT*96QS:68@*"0Q(&5Q("=-)RD@>PIE=F%L(")U<V4@
M)#(B.PI]"F5L<VEF("@D,2!E<2`G02<I('L*=6YS:&EF="!`<&%R7V%R9W,L
M("0R.PI]"F5L<VEF("@D,2!E<2`G3R<I('L*)&]U="`]("0R.PI]"F5L<VEF
M("@D,2!E<2`G8B<I('L*)&)U;F1L92`]("=S:71E)SL*?0IE;'-I9B`H)#$@
M97$@)T(G*2!["B1B=6YD;&4@/2`G86QL)SL*?0IE;'-I9B`H)#$@97$@)W$G
M*2!["B1Q=6EE="`](#$["GT*96QS:68@*"0Q(&5Q("=,)RD@>PIO<&5N("1L
M;V=F:"P@(CX^(BP@)#(@;W(@9&EE(")86%@Z($-A;FYO="!O<&5N(&QO9SH@
M)"$B.PI]"F5L<VEF("@D,2!E<2`G5"<I('L*)&-A8VAE7VYA;64@/2`D,CL*
M?0IS:&EF="A`05)'5BD["FEF("AM>2`D8VUD(#T@)&1I<W1?8VUD>R0Q?2D@
M>PID96QE=&4@)$5.5GLG4$%27U1%35`G?3L*:6YI=%]I;F,H*3L*<F5Q=6ER
M92!005(Z.D1I<W0["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"D@=6YL97-S($!!
M4D=6.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@D7RD@9F]R($!!4D=6.PIE>&ET
M.PI]"GT*=6YS:&EF="!`24Y#+"!`861D7W1O7VEN8SL*?0I]"FEF("@D;W5T
M*2!["GL*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!!<F-H:79E.CI::7`[
M"G)E<75I<F4@1&EG97-T.CI32$$["GT*;7D@)'!A<B`]('-H:69T*$!!4D=6
M*3L*;7D@)'II<#L*:68@*&1E9FEN960@)'!A<BD@>PIO<&5N(&UY("1F:"P@
M)SPG+"`D<&%R(&]R(&1I92`B0V%N;F]T(&9I;F0@)R1P87(G.B`D(2(["F)I
M;FUO9&4H)&9H*3L*8FQE<W,H)&9H+"`G24\Z.D9I;&4G*3L*)'II<"`]($%R
M8VAI=F4Z.EII<"T^;F5W.PHH("1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D
M9F@L("1P87(I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2`I"F]R(&1I92`B
M4F5A9"`G)'!A<B<@97)R;W(Z("0A(CL*?0IM>2`E96YV(#T@9&\@>PII9B`H
M)'II<"!A;F0@;7D@)&UE=&$@/2`D>FEP+3YC;VYT96YT<R@G345402YY;6PG
M*2D@>PHD;65T82`]?B!S+RXJ7G!A<CHD+R]M<SL*)&UE=&$@/7X@<R]>7%,N
M*B\O;7,["B1M971A(#U^("]>("`H6UXZ72LI.B`H+BLI)"]M9SL*?0I].PIL
M;V-A;"`D+R`](%PT.PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@4$%2+"`G
M/"<L("1P87(@;W(@9&EE("(D(3H@)'!A<B(["F)I;FUO9&4H4$%2*3L*9&EE
M("(D<&%R(&ES(&YO="!A(%!!4B!F:6QE(B!U;FQE<W,@/%!!4CX@97$@(E!+
M7#`P,UPP,#0B.PI]"D-R96%T95!A=&@H)&]U="D@.PIM>2`D9F@@/2!)3SHZ
M1FEL92T^;F5W*`HD;W5T+`I)3SHZ1FEL93HZ3U]#4D5!5"@I('P@24\Z.D9I
M;&4Z.D]?5U)/3DQ9*"D@?"!)3SHZ1FEL93HZ3U]44E5.0R@I+`HP-S<W+`HI
M(&]R(&1I92`D(3L*8FEN;6]D92@D9F@I.PHD+R`]("AD969I;F5D("1D871A
M7W!O<RD@/R!<)&1A=&%?<&]S(#H@=6YD968["G-E96L@7T9(+"`P+"`P.PIM
M>2`D;&]A9&5R(#T@<V-A;&%R(#Q?1D@^.PII9B`H(21%3E9[4$%27U9%4D)!
M5$E-?2!A;F0@)&QO861E<B`]?B`O7B@_.B,A?%Q`<F5M*2\I('L*<F5Q=6ER
M92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["E!!4CHZ1FEL=&5R.CI0;V13=')I
M<"T^;F5W+3YA<'!L>2A<)&QO861E<BP@)#`I"GT*9F]R96%C:"!M>2`D:V5Y
M("AS;W)T(&ME>7,@)65N=BD@>PIM>2`D=F%L(#T@)&5N=GLD:V5Y?2!O<B!N
M97AT.PHD=F%L(#T@979A;"`D=F%L(&EF("1V86P@/7X@+UY;)R)=+SL*;7D@
M)&UA9VEC(#T@(E]?14Y67U!!4E\B("X@=6,H)&ME>2D@+B`B7U\B.PIM>2`D
M<V5T(#T@(E!!4E\B("X@=6,H)&ME>2D@+B`B/21V86PB.PHD;&]A9&5R(#U^
M('-[)&UA9VEC*"`K*7U["B1M86=I8R`N("1S970@+B`H)R`G('@@*&QE;F=T
M:"@D,2D@+2!L96YG=&@H)'-E="DI*0I]96<["GT*)&9H+3YP<FEN="@D;&]A
M9&5R*3L*)"\@/2!U;F1E9CL*:68@*"1B=6YD;&4I('L*<F5Q=6ER92!005(Z
M.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["FEN:71?
M:6YC*"D["G)E<75I<F5?;6]D=6QE<R@I.PIM>2!`:6YC(#T@9W)E<"![("$O
M0E-$4$%.+R!]"F=R97`@>PHH)&)U;F1L92!N92`G<VET92<I(&]R"B@D7R!N
M92`D0V]N9FEG.CI#;VYF:6=[87)C:&QI8F5X<'T@86YD"B1?(&YE("1#;VYF
M:6<Z.D-O;F9I9WMP<FEV;&EB97AP?2D["GT@0$E.0SL*;7D@)69I;&5S.PHD
M9FEL97-[)%]]*RL@9F]R($!$>6YA3&]A9&5R.CID;%]S:&%R961?;V)J96-T
M<RP@=F%L=65S("5)3D,["FUY("1L:6)?97AT(#T@)$-O;F9I9SHZ0V]N9FEG
M>VQI8E]E>'1].PIM>2`E=W)I='1E;CL*9F]R96%C:"`H<V]R="!K97ES("5F
M:6QE<RD@>PIM>2`H)&YA;64L("1F:6QE*3L*9F]R96%C:"!M>2`D9&ER("A`
M:6YC*2!["FEF("@D;F%M92`]("1005(Z.DAE879Y.CI&=6QL0V%C:&5[)%]]
M*2!["B1F:6QE(#T@)%\["FQA<W0["GT*96QS:68@*"]>*%Q1)&1I<EQ%7"\H
M+BI;7D-C72DI7%HO:2D@>PHH)&9I;&4L("1N86UE*2`]("@D,2P@)#(I.PIL
M87-T.PI]"F5L<VEF("AM(5XO;&]A9&5R+UM>+UTK+R@N*EM>0V-=*5Q:(2D@
M>PII9B`H;7D@)')E9B`]("1005(Z.DAE879Y.CI-;V1U;&5#86-H97LD,7TI
M('L**"1F:6QE+"`D;F%M92D@/2`H)')E9BP@)#$I.PIL87-T.PI]"F5L<VEF
M("@M9B`B)&1I<B\D,2(I('L**"1F:6QE+"`D;F%M92D@/2`H(B1D:7(O)#$B
M+"`D,2D["FQA<W0["GT*?0I]"FYE>'0@=6YL97-S(&1E9FEN960@)&YA;64@
M86YD(&YO="`D=W)I='1E;GLD;F%M97TK*SL*;F5X="!I9B`A<F5F*"1F:6QE
M*2!A;F0@)&9I;&4@/7X@+UPN7%$D;&EB7V5X=%Q%)"\["F]U=',H(&IO:6X@
M(B(L"G%Q*%!A8VMI;F<@(BDL(')E9B`D9FEL92`_("1F:6QE+3Y[;F%M97T@
M.B`D9FEL92P*<7$H(BXN+BD**3L*;7D@)&-O;G1E;G0["FEF("AR968H)&9I
M;&4I*2!["B1C;VYT96YT(#T@)&9I;&4M/GMB=69].PI]"F5L<V4@>PIO<&5N
M($9)3$4L("<\)RP@)&9I;&4@;W(@9&EE(")#86XG="!O<&5N("1F:6QE.B`D
M(2(["F)I;FUO9&4H1DE,12D["B1C;VYT96YT(#T@/$9)3$4^.PIC;&]S92!&
M24Q%.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/FYE=RT^87!P;'DH7"1C;VYT
M96YT+"`D9FEL92D*:68@(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&YA;64@
M/7X@+UPN*#\Z<&U\:7A\86PI)"]I.PI005(Z.D9I;'1E<CHZ4&%T8VA#;VYT
M96YT+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4L("1N86UE*3L*?0IO
M=71S*'%Q*%=R:71T96X@87,@(B1N86UE(BDI.PHD9F@M/G!R:6YT*")&24Q%
M(BD["B1F:"T^<')I;G0H<&%C:R@G3B<L(&QE;F=T:"@D;F%M92D@*R`Y*2D[
M"B1F:"T^<')I;G0H<W!R:6YT9B@*(B4P.'@O)7,B+"!!<F-H:79E.CI::7`Z
M.F-O;7!U=&5#4D,S,B@D8V]N=&5N="DL("1N86UE"BDI.PHD9F@M/G!R:6YT
M*'!A8VLH)TXG+"!L96YG=&@H)&-O;G1E;G0I*2D["B1F:"T^<')I;G0H)&-O
M;G1E;G0I.PI]"GT*)'II<"T^=W)I=&54;T9I;&5(86YD;&4H)&9H*2!I9B`D
M>FEP.PHD8V%C:&5?;F%M92`]('-U8G-T<B`D8V%C:&5?;F%M92P@,"P@-#`[
M"FEF("@A)&-A8VAE7VYA;64@86YD(&UY("1M=&EM92`]("AS=&%T*"1O=70I
M*5LY72D@>PIM>2`D8W1X(#T@1&EG97-T.CI32$$M/FYE=R@Q*3L*;W!E;BAM
M>2`D9F@L("(\(BP@)&]U="D["F)I;FUO9&4H)&9H*3L*)&-T>"T^861D9FEL
M92@D9F@I.PIC;&]S92@D9F@I.PHD8V%C:&5?;F%M92`]("1C='@M/FAE>&1I
M9V5S=#L*?0HD8V%C:&5?;F%M92`N/2`B7#`B('@@*#0Q("T@;&5N9W1H("1C
M86-H95]N86UE*3L*)&-A8VAE7VYA;64@+CT@(D-!0TA%(CL*)&9H+3YP<FEN
M="@D8V%C:&5?;F%M92D["B1F:"T^<')I;G0H<&%C:R@G3B<L("1F:"T^=&5L
M;"`M(&QE;F=T:"@D;&]A9&5R*2DI.PHD9F@M/G!R:6YT*"1005)?34%'24,I
M.PHD9F@M/F-L;W-E.PIC:&UO9"`P-S4U+"`D;W5T.PIE>&ET.PI]"GL*;&%S
M="!U;FQE<W,@9&5F:6YE9"`D<W1A<G1?<&]S.PI?9FEX7W!R;V=N86UE*"D[
M"G)E<75I<F4@4$%2.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D[
M"GL*<F5Q=6ER92!&:6QE.CI&:6YD.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*
M?0IM>2`D9F@@/2!)3SHZ1FEL92T^;F5W.R`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(R!!<F-H:79E.CI::7`@;W!E<F%T97,@;VX@86X@24\Z.DAA
M;F1L90HD9F@M/F9D;W!E;BAF:6QE;F\H7T9(*2P@)W(G*2!O<B!D:64@(B0A
M.B`D0"(["D%R8VAI=F4Z.EII<#HZ<V5T0VAU;FM3:7IE*"US(%]&2"D["FUY
M("1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL*)'II<"T^<F5A9$9R;VU&:6QE
M2&%N9&QE*"1F:"P@)'!R;V=N86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+
M*"D@;W(@9&EE("(D(3H@)$`B.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ
M92@V-"`J(#$P,C0I.PIP=7-H($!005(Z.DQI8D-A8VAE+"`D>FEP.PHD4$%2
M.CI,:6)#86-H97LD<')O9VYA;65](#T@)'II<#L*)'%U:65T(#T@(21%3E9[
M4$%27T1%0E5'?3L*;W5T<RAQ<2A<)$5.5GM005)?5$5-4'T@/2`B)$5.5GM0
M05)?5$5-4'TB*2D["FEF("AD969I;F5D("1%3E9[4$%27U1%35!]*2![(",@
M<VAO=6QD(&)E('-E="!A="!T:&ES('!O:6YT(0IF;W)E86-H(&UY("1M96UB
M97(@*"`D>FEP+3YM96UB97)S("D@>PIN97AT(&EF("1M96UB97(M/FES1&ER
M96-T;W)Y.PIM>2`D;65M8F5R7VYA;64@/2`D;65M8F5R+3YF:6QE3F%M93L*
M;F5X="!U;FQE<W,@)&UE;6)E<E]N86UE(#U^(&U["EX*+S]S:&QI8B\**#\Z
M)$-O;F9I9SHZ0V]N9FEG>W9E<G-I;VY]+RD_"B@_.B1#;VYF:6<Z.D-O;F9I
M9WMA<F-H;F%M97TO*3\**%M>+UTK*0HD"GUX.PIM>2`D97AT<F%C=%]N86UE
M(#T@)#$["FUY("1D97-T7VYA;64@/2!&:6QE.CI3<&5C+3YC871F:6QE*"1%
M3E9[4$%27U1%35!]+"`D97AT<F%C=%]N86UE*3L*:68@*"UF("1D97-T7VYA
M;64@)B8@+7,@7R`]/2`D;65M8F5R+3YU;F-O;7!R97-S9613:7IE*"DI('L*
M;W5T<RAQ<2A3:VEP<&EN9R`B)&UE;6)E<E]N86UE(B!S:6YC92!I="!A;')E
M861Y(&5X:7-T<R!A="`B)&1E<W1?;F%M92(I*3L*?2!E;'-E('L*;W5T<RAQ
M<2A%>'1R86-T:6YG("(D;65M8F5R7VYA;64B('1O("(D9&5S=%]N86UE(BDI
M.PHD;65M8F5R+3YE>'1R86-T5&]&:6QE3F%M960H)&1E<W1?;F%M92D["F-H
M;6]D*#`U-34L("1D97-T7VYA;64I(&EF("1>3R!E<2`B:'!U>"(["GT*?0I]
M"GT*=6YL97-S("@D4$%2.CI,:6)#86-H97LD<')O9VYA;65]*2!["F1I92`\
M/"`B+B(@=6YL97-S($!!4D=6.PI5<V%G93H@)#`@6R`M06QI8BYP87(@72!;
M("U)9&ER(%T@6R`M36UO9'5L92!=(%L@<W)C+G!A<B!=(%L@<')O9W)A;2YP
M;"!="B0P(%L@+4)\+6(@72!;+4]O=71F:6QE72!S<F,N<&%R"BX*)$5.5GM0
M05)?4%)/1TY!345](#T@)'!R;V=N86UE(#T@)#`@/2!S:&EF="A`05)'5BD[
M"GT*<W5B($-R96%T95!A=&@@>PIM>2`H)&YA;64I(#T@0%\["G)E<75I<F4@
M1FEL93HZ0F%S96YA;64["FUY("@D8F%S96YA;64L("1P871H+"`D97AT*2`]
M($9I;&4Z.D)A<V5N86UE.CIF:6QE<&%R<V4H)&YA;64L("@G7"XN*B<I*3L*
M<F5Q=6ER92!&:6QE.CI0871H.PI&:6QE.CI0871H.CIM:W!A=&@H)'!A=&@I
M('5N;&5S<R@M92`D<&%T:"D[(",@;6MP871H(&1I97,@=VET:"!E<G)O<@I]
M"G-U8B!R97%U:7)E7VUO9'5L97,@>PIR97%U:7)E(&QI8CL*<F5Q=6ER92!$
M>6YA3&]A9&5R.PIR97%U:7)E(&EN=&5G97(["G)E<75I<F4@<W1R:6-T.PIR
M97%U:7)E('=A<FYI;F=S.PIR97%U:7)E('9A<G,["G)E<75I<F4@0V%R<#L*
M<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%<G)N;SL*<F5Q=6ER92!%
M>'!O<G1E<CHZ2&5A=GD["G)E<75I<F4@17AP;W)T97(["G)E<75I<F4@1F-N
M=&P["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI3<&5C.PIR
M97%U:7)E(%A33&]A9&5R.PIR97%U:7)E($-O;F9I9SL*<F5Q=6ER92!)3SHZ
M2&%N9&QE.PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($-O;7!R97-S.CI:
M;&EB.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!$:6=E<W0Z.E-(
M03L*<F5Q=6ER92!005(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!0
M05(Z.D1I<W0["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PIR97%U
M:7)E(%!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0["G)E<75I<F4@871T<FEB
M=71E<SL*979A;"![(')E<75I<F4@0W=D('T["F5V86P@>R!R97%U:7)E(%=I
M;C,R('T["F5V86P@>R!R97%U:7)E(%-C86QA<CHZ571I;"!].PIE=F%L('L@
M<F5Q=6ER92!!<F-H:79E.CI5;GII<#HZ0G5R<W0@?3L*979A;"![(')E<75I
M<F4@5&EE.CI(87-H.CI.86UE9$-A<'1U<F4@?3L*979A;"![(')E<75I<F4@
M4&5R;$E/.R!R97%U:7)E(%!E<FQ)3SHZ<V-A;&%R('T["F5V86P@>R!R97%U
M:7)E('5T9C@@?3L*?0IS=6(@7W-E=%]P87)?=&5M<"!["FEF("AD969I;F5D
M("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\I
M('L*)'!A<E]T96UP(#T@)#$["G)E='5R;CL*?0IF;W)E86-H(&UY("1P871H
M("@**&UA<"`D14Y6>R1??2P@<7<H(%!!4E]435!$25(@5$U01$E2(%1%35!$
M25(@5$5-4"!435`@*2DL"G%W*"!#.EQ<5$5-4"`O=&UP("X@*0HI('L*;F5X
M="!U;FQE<W,@9&5F:6YE9"`D<&%T:"!A;F0@+60@)'!A=&@@86YD("UW("1P
M871H.PIM>2`D=7-E<FYA;64["FUY("1P=W5I9#L*979A;"![*"1P=W5I9"D@
M/2!G971P=W5I9"@D/BD@:68@9&5F:6YE9"`D/CM].PII9B`H(&1E9FEN960H
M)E=I;C,R.CI,;V=I;DYA;64I("D@>PHD=7-E<FYA;64@/2`F5VEN,S(Z.DQO
M9VEN3F%M93L*?0IE;'-I9B`H9&5F:6YE9"`D<'=U:60I('L*)'5S97)N86UE
M(#T@)'!W=6ED.PI]"F5L<V4@>PHD=7-E<FYA;64@/2`D14Y6>U5315).04U%
M?2!\?"`D14Y6>U5315)]('Q\("=365-414TG.PI]"B1U<V5R;F%M92`]?B!S
M+UQ7+U\O9SL*;7D@)'-T;7!D:7(@/2`B)'!A=&@D0V]N9FEG>U]D96QI;7UP
M87(M(BYU;G!A8VLH(D@J(BP@)'5S97)N86UE*3L*;6MD:7(@)'-T;7!D:7(L
M(#`W-34["FEF("@A)$5.5GM005)?0TQ%04Y](&%N9"!M>2`D;71I;64@/2`H
M<W1A="@D<')O9VYA;64I*5LY72D@>PIO<&5N("AM>2`D9F@L("(\(BX@)'!R
M;V=N86UE*3L*<V5E:R`D9F@L("TQ."P@,CL*<WES<F5A9"`D9F@L(&UY("1B
M=68L(#8["FEF("@D8G5F(&5Q(")<,$-!0TA%(BD@>PIS965K("1F:"P@+34X
M+"`R.PIS>7-R96%D("1F:"P@)&)U9BP@-#$["B1B=68@/7X@<R]<,"\O9SL*
M)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?6-A8VAE+2(@+B`D8G5F.PI]
M"F5L<V4@>PIM>2`D9&EG97-T(#T@979A;`I["G)E<75I<F4@1&EG97-T.CI3
M2$$["FUY("1C='@@/2!$:6=E<W0Z.E-(02T^;F5W*#$I.PIO<&5N*&UY("1F
M:"P@(CPB+"`D<')O9VYA;64I.PIB:6YM;V1E*"1F:"D["B1C='@M/F%D9&9I
M;&4H)&9H*3L*8VQO<V4H)&9H*3L*)&-T>"T^:&5X9&EG97-T.PI]("\O("1M
M=&EM93L*)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?6-A8VAE+21D:6=E
M<W0B.PI]"F-L;W-E*"1F:"D["GT*96QS92!["B1%3E9[4$%27T-,14%.?2`]
M(#$["B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UT96UP+20D(CL*?0HD
M14Y6>U!!4E]414U0?2`]("1S=&UP9&ER.PIM:V1I<B`D<W1M<&1I<BP@,#<U
M-3L*;&%S=#L*?0HD<&%R7W1E;7`@/2`D,2!I9B`D14Y6>U!!4E]414U0?2!A
M;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO.PI]"G-U8B!?=&5M<&9I;&4@
M>PIM>2`H)&YA;64L("1C;VYT96YT<RP@)&UO9&4I(#T@0%\["FUY("1F=6QL
M;F%M92`]("(D<&%R7W1E;7`O)&YA;64B.PIU;FQE<W,@*"UE("1F=6QL;F%M
M92D@>PIM>2`D=&5M<&YA;64@/2`B)&9U;&QN86UE+B0D(CL*;W!E;B!M>2`D
M9F@L("<^)RP@)'1E;7!N86UE(&]R(&1I92`B8V%N)W0@=W)I=&4@)'1E;7!N
M86UE.B`D(2(["F)I;FUO9&4@)&9H.PIP<FEN="`D9F@@)&-O;G1E;G1S.PIC
M;&]S92`D9F@["F-H;6]D("1M;V1E+"`D=&5M<&YA;64@:68@9&5F:6YE9"`D
M;6]D93L*<F5N86UE*"1T96UP;F%M92P@)&9U;&QN86UE*2!O<B!U;FQI;FLH
M)'1E;7!N86UE*3L*?0IR971U<FX@)&9U;&QN86UE.PI]"G-U8B!?<V5T7W!R
M;V=N86UE('L*:68@*&1E9FEN960@)$5.5GM005)?4%)/1TY!345](&%N9"`D
M14Y6>U!!4E]04D]'3D%-17T@/7X@+R@N*RDO*2!["B1P<F]G;F%M92`]("0Q
M.PI]"B1P<F]G;F%M92!\?#T@)#`["FEF("@D14Y6>U!!4E]414U0?2!A;F0@
M:6YD97@H)'!R;V=N86UE+"`D14Y6>U!!4E]414U0?2D@/CT@,"D@>PHD<')O
M9VYA;64@/2!S=6)S='(H)'!R;V=N86UE+"!R:6YD97@H)'!R;V=N86UE+"`D
M0V]N9FEG>U]D96QI;7TI("L@,2D["GT*:68@*"$D14Y6>U!!4E]04D]'3D%-
M17T@;W(@:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI(#X](#`I
M('L*:68@*&]P96X@;7D@)&9H+"`G/"<L("1P<F]G;F%M92D@>PIR971U<FX@
M:68@+7,@)&9H.PI]"FEF("@M<R`B)'!R;V=N86UE)$-O;F9I9WM?97AE?2(I
M('L*)'!R;V=N86UE("X]("1#;VYF:6=[7V5X97T["G)E='5R;CL*?0I]"F9O
M<F5A8V@@;7D@)&1I<B`H<W!L:70@+UQ1)$-O;F9I9WMP871H7W-E<'U<12\L
M("1%3E9[4$%42'TI('L*;F5X="!I9B!E>&ES=',@)$5.5GM005)?5$5-4'T@
M86YD("1D:7(@97$@)$5.5GM005)?5$5-4'T["B1D:7(@/7X@<R]<421#;VYF
M:6=[7V1E;&EM?5Q%)"\O.PHH*"1P<F]G;F%M92`]("(D9&ER)$-O;F9I9WM?
M9&5L:6U])'!R;V=N86UE)$-O;F9I9WM?97AE?2(I+"!L87-T*0II9B`M<R`B
M)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M921#;VYF:6=[7V5X97TB.PHH
M*"1P<F]G;F%M92`]("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(BDL
M(&QA<W0I"FEF("US("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(CL*
M?0I]"G-U8B!?9FEX7W!R;V=N86UE('L*)#`@/2`D<')O9VYA;64@?'P]("1%
M3E9[4$%27U!23T=.04U%?3L*:68@*&EN9&5X*"1P<F]G;F%M92P@)$-O;F9I
M9WM?9&5L:6U]*2`\(#`I('L*)'!R;V=N86UE(#T@(BXD0V]N9FEG>U]D96QI
M;7TD<')O9VYA;64B.PI]"FUY("1P=V0@/2`H9&5F:6YE9"`F0W=D.CIG971C
M=V0I(#\@0W=D.CIG971C=V0H*0HZ("@H9&5F:6YE9"`F5VEN,S(Z.D=E=$-W
M9"D@/R!7:6XS,CHZ1V5T0W=D*"D@.B!@<'=D8"D["F-H;VUP*"1P=V0I.PHD
M<')O9VYA;64@/7X@<R]>*#\]7"Y<+C]<421#;VYF:6=[7V1E;&EM?5Q%*2\D
M<'=D)$-O;F9I9WM?9&5L:6U]+SL*)$5.5GM005)?4%)/1TY!345](#T@)'!R
M;V=N86UE.PI]"G-U8B!?<&%R7VEN:71?96YV('L*:68@*"`D14Y6>U!!4E])
M3DE424%,25I%1'TK*R`]/2`Q("D@>PIR971U<FX["GT@96QS92!["B1%3E9[
M4$%27TE.251)04Q)6D5$?2`](#(["GT*9F]R("AQ=R@@4U!!5TY%1"!414U0
M($-,14%.($1%0E5'($-!0TA%(%!23T=.04U%("D@*2!["F1E;&5T92`D14Y6
M>R=005)?)RXD7WT["GT*9F]R("AQ=R\@5$U01$E2(%1%35`@0TQ%04X@1$5"
M54<@+RD@>PHD14Y6>R=005)?)RXD7WT@/2`D14Y6>R=005)?1TQ/0D%,7R<N
M)%]](&EF(&5X:7-T<R`D14Y6>R=005)?1TQ/0D%,7R<N)%]].PI]"FUY("1P
M87)?8VQE86X@/2`B7U]%3E9?4$%27T-,14%.7U\@("`@("`@("`@("`@("`B
M.PII9B`H)$5.5GM005)?5$5-4'TI('L*9&5L971E("1%3E9[4$%27T-,14%.
M?3L*?0IE;'-I9B`H(65X:7-T<R`D14Y6>U!!4E]'3$]"04Q?0TQ%04Y]*2![
M"FUY("1V86QU92`]('-U8G-T<B@D<&%R7V-L96%N+"`Q,B`K(&QE;F=T:"@B
M0TQ%04XB*2D["B1%3E9[4$%27T-,14%.?2`]("0Q(&EF("1V86QU92`]?B`O
M7E!!4E]#3$5!3CTH7%,K*2\["GT*?0IS=6(@;W5T<R!["G)E='5R;B!I9B`D
M<75I970["FEF("@D;&]G9F@I('L*<')I;G0@)&QO9V9H(")`7UQN(CL*?0IE
M;'-E('L*<')I;G0@(D!?7&XB.PI]"GT*<W5B(&EN:71?:6YC('L*<F5Q=6ER
M92!#;VYF:6<["G!U<V@@0$E.0RP@9W)E<"!D969I;F5D+"!M87`@)$-O;F9I
M9SHZ0V]N9FEG>R1??2P@<7<H"F%R8VAL:6)E>'`@<')I=FQI8F5X<"!S:71E
M87)C:&5X<"!S:71E;&EB97AP"G9E;F1O<F%R8VAE>'`@=F5N9&]R;&EB97AP
M"BD["GT*<&%C:V%G92!M86EN.PIR97%U:7)E(%!!4CL*=6YS:&EF="!`24Y#
M+"!<)E!!4CHZ9FEN9%]P87(["E!!4BT^:6UP;W)T*$!P87)?87)G<RD["F1I
M92!Q<2AP87(N<&PZ($-A;B=T(&]P96X@<&5R;"!S8W)I<'0@(B1P<F]G;F%M
M92(Z($YO('-U8V@@9FEL92!O<B!D:7)E8W1O<GE<;BD*=6YL97-S("UE("1P
M<F]G;F%M93L*9&\@)'!R;V=N86UE.PI#3U)%.CIE>&ET*"0Q*2!I9B`H)$`@
M/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)$`@:68@)$`["GT["B0Z
M.E]?15)23U(@/2`D0"!I9B`D0#L*?0I#3U)%.CIE>&ET*"0Q*2!I9B`H)#HZ
M7U]%4E)/4B`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D.CI?7T52
M4D]2(&EF("0Z.E]?15)23U(["C$["E]?14Y$7U\*``!P97)L>'-I+F,`7U]%
M3E9?4$%27T-,14%.7U\@("`@("`@("`@("`@("```````1L#.P```-`````9
M__^,?```!*C__Y"<````[/__D4P```$H__^1G````4C__Y(T```!>/__E(P`
M``&T__^5[````>S__Y:,```"&/__ELP```(X__^7+````G3__YA$```"L/__
MF$P```+$__^:/````P#__YI<```#%/__FY0```,X__^='````US__YV,```#
MB/__G;P```.H__^>;````_3__Z2\```$,/__J'P```1L__^H[```!.S__[\T
M```%*/__OZ0```5,___!!```!8@````4``````%Z4@`!>`X!&PP/H`$`````
M```X````'/__CZ@```"P`$:&#H<-B`R)"XH*BPF,"(T'C@:/!48.P`("@@K/
MSLW,R\K)R,?&#J`!0@L````<````6/__D!P```!0`%2.!H\%1@[0`G3/S@Z@
M`0```"P```!X__^03````)@`2HH*BPF,"(T'C@:/!48.T`("AL_.S<S+R@Z@
M`0```````#@```"H__^0M````E(`2H8.APV(#(D+B@J+"8P(C0>.!H\%1@[0
M`@,"0,_.S<S+RLG(Q\8.H`$``````#0```#D__^2T````5X`2H<-B`R)"XH*
MBPF,"(T'C@:/!48.V`,#`4S/SLW,R\K)R,<.H`$`````*````1S__Y/X````
MG`!4BPF,"(T'C@:/!48.V`,"@,_.S<S+#J`!```````<```!2/__E&P````\
M`$R.!H\%1@[``F3/S@Z@`0```#@```%H__^4C````%H`1H8.APV(#(D+B@J+
M"8P(C0>.!H\%1@[(`@),S\[-S,O*R<C'Q@Z@`0```````#@```&D__^4L```
M`18`2H8.APV(#(D+B@J+"8P(C0>.!H\%1@[00@,!!,_.S<S+RLG(Q\8.H`$`
M`````!````'@__^5C`````8`````````.````?3__Y6````![@!*A@Z'#8@,
MB0N*"HL)C`B-!XX&CP5&#N`C`P'<S\[-S,O*R<C'Q@Z@`0``````$````C#_
M_Y<T````'@`````````@```"1/__ET````$V``+\C@:/!48.P`)8S\X.H`$`
M```````@```":/__F%0```&(`%2.!H\%1@[P`@,!;,_.#J`!```````H```"
MC/__F;@```!P`%J.!H\%1@[``GX*S\X.H`%""T@.H`'.SP```````!P```*X
M__^9_````"X`1HX&CP5&#L`"8,_.#J`!````2````MC__YH,````K`!&A@Z'
M#8@,B0N*"HL)C`B-!XX&CP5*#L`";`K/SLW,R\K)R,?&#J`!1@L":,_.S<S+
MRLG(Q\8.H`$``````#@```,D__^:<```!DH`5(8.APV(#(D+B@J+"8P(C0>.
M!H\%1@Z(A0(#!B[/SLW,R\K)R,?&#J`!`````#@```-@__^@A````\``1H8.
MAPV(#(D+B@J+"8P(C0>.!H\%1@[``@,#LL_.S<S+RLG(Q\8.H`$``````#@`
M``.<__^D"````&P`1HH*BPF,"(T'C@:/!48.P`("4@K/SLW,R\H.H`%&"T;/
MSLW,R\H.H`$``````$````/8__^'S````BH`1H8.APV(#(D+B@J+"8P(C0>.
M!H\%1@[8`@,!\@K/SLW,R\K)R,?&#J`!0@L`````````````.```!!S__Z/X
M```61`!8A@Z'#8@,B0N*"HL)C`B-!XX&CP5&#M`'`Q8DS\[-S,O*R<C'Q@Z@
M`0``````(```!%C__[H$````;`!*C@:/!48.P`("6L_.#J`!````````.```
M!'S__[I0```!8`!,A@Z'#8@,B0N*"HL)C`B-!XX&CP5>#L`"`NP*S\[-S,O*
MR<C'Q@Z@`4(+````-```!+C__[MT```!&`!&B`R)"XH*BPF,"(T'C@:/!6X.
MP`("N@K/SLW,R\K)R`Z@`48+````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````#__________P``````````____
M______\````````````````````!``````````$``````````0````````*R
M``````````\````````$-@`````````,````````&'``````````#0``````
M`%8(`````&___O4````````"&``````````%````````#"``````````!@``
M``````+P``````````H````````$5``````````+`````````!@`````````
M%0````````````````````,```````"MF``````````"````````!8@`````
M````%``````````'`````````!<````````2Z``````````'````````$'@`
M````````"`````````)P``````````D`````````&``````````8````````
M````````;___^P`````(```!`````&____D`````````#@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````J_@`````````````````
M````````````&,8````````8Y@```````!D&````````&28````````91@``
M`````!EF````````&88````````9I@```````!G&````````&>8````````:
M!@```````!HF````````&D8````````:9@```````!J&````````&J8`````
M```:Q@```````!KF````````&P8````````;)@```````!M&````````&V8`
M```````;A@```````!NF````````&\8````````;Y@```````!P&````````
M'"8````````<1@```````!QF````````'(8````````<I@```````!S&````
M````'.8````````=!@```````!TF````````'48````````=9@```````!V&
M````````':8````````=Q@```````!WF````````'@8````````>)@``````
M`!Y&````````'F8````````>A@```````!ZF````````'L8````````>Y@``
M`````!\&````````'R8````````?1@```````!]F````````'X8````````?
MI@```````!_&````````'^8````````@!@```````"`8````````````````
M`````````````%8(`````````````````````````````!AP````````````
M````````````````````````````````````````````````````````````
M`````````````````````+``_____P````````````!6*@```````%8P````
M``````````````!6,@```````%8V````````5CX```````!6J@```````%9&
M``````````````````!62@```````%90``````````````````!9#$=#0SH@
M*$%L<&EN92`X+C,N,"D@."XS+C``1T-#.B`H06QP:6YE(#DN,BXP*2`Y+C(N
M,```+G-H<W1R=&%B`"YI;G1E<G``+F=N=2YH87-H`"YD>6YS>6T`+F1Y;G-T
M<@`N<F5L82YD>6X`+G)E;&$N<&QT`"YI;FET`"YT97AT`"YF:6YI`"YR;V1A
M=&$`+F5H7V9R86UE7VAD<@`N96A?9G)A;64`+F-T;W)S`"YD=&]R<P`N9'EN
M86UI8P`N9V]T`"YD871A`"YB<W,`+F-O;6UE;G0`````````````````````
M````````````````````````````````````````````````````````````
M```````````+`````0`````````"`````````@`````````"```````````8
M`````````````````````0``````````````$V____8``````````@``````
M``(8`````````A@`````````V`````,```````````````@`````````````
M`!T````+``````````(````````"\`````````+P````````"3`````$````
M`@`````````(`````````!@````E`````P`````````"````````#"``````
M```,(`````````14`````````````````````0``````````````+0````0`
M`````````@```````!!X````````$'@````````"<`````,`````````````
M``@`````````&````#<````$`````````$(````````2Z````````!+H````
M````!8@````#````$0`````````(`````````!@```!!`````0`````````&
M````````&'`````````8<``````````H`````````````````````@``````
M````````/`````$`````````!@```````!B8````````&)@````````'@```
M``````````````````0`````````(````$<````!``````````8````````@
M&````````"`8````````-?`````````````````````(``````````````!-
M`````0`````````&````````5@@```````!6"``````````B````````````
M`````````@``````````````4P````$``````````@```````%8J````````
M5BH````````]<`````````````````````(``````````````%L````!````
M``````(```````"3G````````).<`````````-0````````````````````$
M``````````````!I`````0`````````"````````E'````````"4<```````
M``3P````````````````````"```````````````<P````$``````````P``
M`````*O8````````F]@`````````$`````````````````````@`````````
M`````'H````!``````````,```````"KZ````````)OH`````````!``````
M```````````````(``````````````"!````!@`````````#````````J_@`
M``````";^`````````&@````!```````````````"``````````0````B@``
M``$``````````P```````*V8````````G9@````````":```````````````
M``````@`````````"````(\````!``````````,```````"P`````````*``
M`````````'@````````````````````(``````````````"5````"```````
M```#````````L'@```````"@>````````!!@````````````````````"```
M````````````F@````$`````````,```````````````````H'@`````````
M-`````````````````````$``````````0````$````#````````````````
L`````````````*"L`````````*,````````````````````!````````````
